# coding: utf-8
import pprint
import six
from enum import Enum



class UserAccountRole:

    swagger_types = {
    
        'account': 'int',
        'applies_on_sub_account': 'bool',
        'id': 'int',
        'role': 'int',
        'user': 'int',
        'version': 'int',
    }

    attribute_map = {
        'account': 'account','applies_on_sub_account': 'appliesOnSubAccount','id': 'id','role': 'role','user': 'user','version': 'version',
    }

    
    _account = None
    _applies_on_sub_account = None
    _id = None
    _role = None
    _user = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.account = kwargs.get('account', None)
        self.applies_on_sub_account = kwargs.get('applies_on_sub_account', None)
        self.id = kwargs.get('id', None)
        self.role = kwargs.get('role', None)
        self.user = kwargs.get('user', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def account(self):
        """Gets the account of this UserAccountRole.

            

        :return: The account of this UserAccountRole.
        :rtype: int
        """
        return self._account

    @account.setter
    def account(self, account):
        """Sets the account of this UserAccountRole.

            

        :param account: The account of this UserAccountRole.
        :type: int
        """

        self._account = account
    
    @property
    def applies_on_sub_account(self):
        """Gets the applies_on_sub_account of this UserAccountRole.

            

        :return: The applies_on_sub_account of this UserAccountRole.
        :rtype: bool
        """
        return self._applies_on_sub_account

    @applies_on_sub_account.setter
    def applies_on_sub_account(self, applies_on_sub_account):
        """Sets the applies_on_sub_account of this UserAccountRole.

            

        :param applies_on_sub_account: The applies_on_sub_account of this UserAccountRole.
        :type: bool
        """

        self._applies_on_sub_account = applies_on_sub_account
    
    @property
    def id(self):
        """Gets the id of this UserAccountRole.

            A unique identifier for the object.

        :return: The id of this UserAccountRole.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UserAccountRole.

            A unique identifier for the object.

        :param id: The id of this UserAccountRole.
        :type: int
        """

        self._id = id
    
    @property
    def role(self):
        """Gets the role of this UserAccountRole.

            

        :return: The role of this UserAccountRole.
        :rtype: int
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this UserAccountRole.

            

        :param role: The role of this UserAccountRole.
        :type: int
        """

        self._role = role
    
    @property
    def user(self):
        """Gets the user of this UserAccountRole.

            

        :return: The user of this UserAccountRole.
        :rtype: int
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this UserAccountRole.

            

        :param user: The user of this UserAccountRole.
        :type: int
        """

        self._user = user
    
    @property
    def version(self):
        """Gets the version of this UserAccountRole.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this UserAccountRole.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this UserAccountRole.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this UserAccountRole.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(UserAccountRole, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, UserAccountRole):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
from enum import Enum, unique


@unique
class ShopifySubscriptionState(Enum):
    
    INITIATING = "INITIATING"
    FAILED = "FAILED"
    ACTIVE = "ACTIVE"
    SUSPENDED = "SUSPENDED"
    TERMINATING = "TERMINATING"
    TERMINATED = "TERMINATED"




# coding: utf-8
import pprint
import six
from enum import Enum



class PaymentConnector:

    swagger_types = {
    
        'data_collection_type': 'DataCollectionType',
        'deprecated': 'bool',
        'deprecation_reason': 'dict(str, str)',
        'description': 'dict(str, str)',
        'feature': 'Feature',
        'id': 'int',
        'name': 'dict(str, str)',
        'payment_method': 'int',
        'payment_method_brand': 'PaymentMethodBrand',
        'primary_risk_taker': 'PaymentPrimaryRiskTaker',
        'processor': 'int',
        'supported_currencies': 'list[str]',
        'supported_customers_presences': 'list[CustomersPresence]',
        'supported_features': 'list[int]',
    }

    attribute_map = {
        'data_collection_type': 'dataCollectionType','deprecated': 'deprecated','deprecation_reason': 'deprecationReason','description': 'description','feature': 'feature','id': 'id','name': 'name','payment_method': 'paymentMethod','payment_method_brand': 'paymentMethodBrand','primary_risk_taker': 'primaryRiskTaker','processor': 'processor','supported_currencies': 'supportedCurrencies','supported_customers_presences': 'supportedCustomersPresences','supported_features': 'supportedFeatures',
    }

    
    _data_collection_type = None
    _deprecated = None
    _deprecation_reason = None
    _description = None
    _feature = None
    _id = None
    _name = None
    _payment_method = None
    _payment_method_brand = None
    _primary_risk_taker = None
    _processor = None
    _supported_currencies = None
    _supported_customers_presences = None
    _supported_features = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.data_collection_type = kwargs.get('data_collection_type', None)
        self.deprecated = kwargs.get('deprecated', None)
        self.deprecation_reason = kwargs.get('deprecation_reason', None)
        self.description = kwargs.get('description', None)
        self.feature = kwargs.get('feature', None)
        self.id = kwargs.get('id', None)
        self.name = kwargs.get('name', None)
        self.payment_method = kwargs.get('payment_method', None)
        self.payment_method_brand = kwargs.get('payment_method_brand', None)
        self.primary_risk_taker = kwargs.get('primary_risk_taker', None)
        self.processor = kwargs.get('processor', None)
        self.supported_currencies = kwargs.get('supported_currencies', None)
        self.supported_customers_presences = kwargs.get('supported_customers_presences', None)
        self.supported_features = kwargs.get('supported_features', None)
        

    
    @property
    def data_collection_type(self):
        """Gets the data_collection_type of this PaymentConnector.

            

        :return: The data_collection_type of this PaymentConnector.
        :rtype: DataCollectionType
        """
        return self._data_collection_type

    @data_collection_type.setter
    def data_collection_type(self, data_collection_type):
        """Sets the data_collection_type of this PaymentConnector.

            

        :param data_collection_type: The data_collection_type of this PaymentConnector.
        :type: DataCollectionType
        """

        self._data_collection_type = data_collection_type
    
    @property
    def deprecated(self):
        """Gets the deprecated of this PaymentConnector.

            

        :return: The deprecated of this PaymentConnector.
        :rtype: bool
        """
        return self._deprecated

    @deprecated.setter
    def deprecated(self, deprecated):
        """Sets the deprecated of this PaymentConnector.

            

        :param deprecated: The deprecated of this PaymentConnector.
        :type: bool
        """

        self._deprecated = deprecated
    
    @property
    def deprecation_reason(self):
        """Gets the deprecation_reason of this PaymentConnector.

            

        :return: The deprecation_reason of this PaymentConnector.
        :rtype: dict(str, str)
        """
        return self._deprecation_reason

    @deprecation_reason.setter
    def deprecation_reason(self, deprecation_reason):
        """Sets the deprecation_reason of this PaymentConnector.

            

        :param deprecation_reason: The deprecation_reason of this PaymentConnector.
        :type: dict(str, str)
        """

        self._deprecation_reason = deprecation_reason
    
    @property
    def description(self):
        """Gets the description of this PaymentConnector.

            The localized description of the object.

        :return: The description of this PaymentConnector.
        :rtype: dict(str, str)
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this PaymentConnector.

            The localized description of the object.

        :param description: The description of this PaymentConnector.
        :type: dict(str, str)
        """

        self._description = description
    
    @property
    def feature(self):
        """Gets the feature of this PaymentConnector.

            

        :return: The feature of this PaymentConnector.
        :rtype: Feature
        """
        return self._feature

    @feature.setter
    def feature(self, feature):
        """Sets the feature of this PaymentConnector.

            

        :param feature: The feature of this PaymentConnector.
        :type: Feature
        """

        self._feature = feature
    
    @property
    def id(self):
        """Gets the id of this PaymentConnector.

            A unique identifier for the object.

        :return: The id of this PaymentConnector.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PaymentConnector.

            A unique identifier for the object.

        :param id: The id of this PaymentConnector.
        :type: int
        """

        self._id = id
    
    @property
    def name(self):
        """Gets the name of this PaymentConnector.

            The localized name of the object.

        :return: The name of this PaymentConnector.
        :rtype: dict(str, str)
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PaymentConnector.

            The localized name of the object.

        :param name: The name of this PaymentConnector.
        :type: dict(str, str)
        """

        self._name = name
    
    @property
    def payment_method(self):
        """Gets the payment_method of this PaymentConnector.

            

        :return: The payment_method of this PaymentConnector.
        :rtype: int
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this PaymentConnector.

            

        :param payment_method: The payment_method of this PaymentConnector.
        :type: int
        """

        self._payment_method = payment_method
    
    @property
    def payment_method_brand(self):
        """Gets the payment_method_brand of this PaymentConnector.

            

        :return: The payment_method_brand of this PaymentConnector.
        :rtype: PaymentMethodBrand
        """
        return self._payment_method_brand

    @payment_method_brand.setter
    def payment_method_brand(self, payment_method_brand):
        """Sets the payment_method_brand of this PaymentConnector.

            

        :param payment_method_brand: The payment_method_brand of this PaymentConnector.
        :type: PaymentMethodBrand
        """

        self._payment_method_brand = payment_method_brand
    
    @property
    def primary_risk_taker(self):
        """Gets the primary_risk_taker of this PaymentConnector.

            

        :return: The primary_risk_taker of this PaymentConnector.
        :rtype: PaymentPrimaryRiskTaker
        """
        return self._primary_risk_taker

    @primary_risk_taker.setter
    def primary_risk_taker(self, primary_risk_taker):
        """Sets the primary_risk_taker of this PaymentConnector.

            

        :param primary_risk_taker: The primary_risk_taker of this PaymentConnector.
        :type: PaymentPrimaryRiskTaker
        """

        self._primary_risk_taker = primary_risk_taker
    
    @property
    def processor(self):
        """Gets the processor of this PaymentConnector.

            

        :return: The processor of this PaymentConnector.
        :rtype: int
        """
        return self._processor

    @processor.setter
    def processor(self, processor):
        """Sets the processor of this PaymentConnector.

            

        :param processor: The processor of this PaymentConnector.
        :type: int
        """

        self._processor = processor
    
    @property
    def supported_currencies(self):
        """Gets the supported_currencies of this PaymentConnector.

            

        :return: The supported_currencies of this PaymentConnector.
        :rtype: list[str]
        """
        return self._supported_currencies

    @supported_currencies.setter
    def supported_currencies(self, supported_currencies):
        """Sets the supported_currencies of this PaymentConnector.

            

        :param supported_currencies: The supported_currencies of this PaymentConnector.
        :type: list[str]
        """

        self._supported_currencies = supported_currencies
    
    @property
    def supported_customers_presences(self):
        """Gets the supported_customers_presences of this PaymentConnector.

            

        :return: The supported_customers_presences of this PaymentConnector.
        :rtype: list[CustomersPresence]
        """
        return self._supported_customers_presences

    @supported_customers_presences.setter
    def supported_customers_presences(self, supported_customers_presences):
        """Sets the supported_customers_presences of this PaymentConnector.

            

        :param supported_customers_presences: The supported_customers_presences of this PaymentConnector.
        :type: list[CustomersPresence]
        """

        self._supported_customers_presences = supported_customers_presences
    
    @property
    def supported_features(self):
        """Gets the supported_features of this PaymentConnector.

            

        :return: The supported_features of this PaymentConnector.
        :rtype: list[int]
        """
        return self._supported_features

    @supported_features.setter
    def supported_features(self, supported_features):
        """Sets the supported_features of this PaymentConnector.

            

        :param supported_features: The supported_features of this PaymentConnector.
        :type: list[int]
        """

        self._supported_features = supported_features
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(PaymentConnector, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, PaymentConnector):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class CardholderAuthentication:

    swagger_types = {
    
        'authentication_identifier': 'str',
        'authentication_response': 'CardAuthenticationResponse',
        'authentication_value': 'str',
        'electronic_commerce_indicator': 'str',
        'version': 'CardAuthenticationVersion',
    }

    attribute_map = {
        'authentication_identifier': 'authenticationIdentifier','authentication_response': 'authenticationResponse','authentication_value': 'authenticationValue','electronic_commerce_indicator': 'electronicCommerceIndicator','version': 'version',
    }

    
    _authentication_identifier = None
    _authentication_response = None
    _authentication_value = None
    _electronic_commerce_indicator = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.authentication_identifier = kwargs.get('authentication_identifier', None)
        self.authentication_response = kwargs.get('authentication_response', None)
        self.authentication_value = kwargs.get('authentication_value', None)
        self.electronic_commerce_indicator = kwargs.get('electronic_commerce_indicator', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def authentication_identifier(self):
        """Gets the authentication_identifier of this CardholderAuthentication.

            The authentication identifier as assigned by authentication system (e.g. XID or DSTransactionID).

        :return: The authentication_identifier of this CardholderAuthentication.
        :rtype: str
        """
        return self._authentication_identifier

    @authentication_identifier.setter
    def authentication_identifier(self, authentication_identifier):
        """Sets the authentication_identifier of this CardholderAuthentication.

            The authentication identifier as assigned by authentication system (e.g. XID or DSTransactionID).

        :param authentication_identifier: The authentication_identifier of this CardholderAuthentication.
        :type: str
        """

        self._authentication_identifier = authentication_identifier
    
    @property
    def authentication_response(self):
        """Gets the authentication_response of this CardholderAuthentication.

            

        :return: The authentication_response of this CardholderAuthentication.
        :rtype: CardAuthenticationResponse
        """
        return self._authentication_response

    @authentication_response.setter
    def authentication_response(self, authentication_response):
        """Sets the authentication_response of this CardholderAuthentication.

            

        :param authentication_response: The authentication_response of this CardholderAuthentication.
        :type: CardAuthenticationResponse
        """

        self._authentication_response = authentication_response
    
    @property
    def authentication_value(self):
        """Gets the authentication_value of this CardholderAuthentication.

            The cardholder authentication value. Also known as Cardholder Authentication Verification Value (CAVV).

        :return: The authentication_value of this CardholderAuthentication.
        :rtype: str
        """
        return self._authentication_value

    @authentication_value.setter
    def authentication_value(self, authentication_value):
        """Sets the authentication_value of this CardholderAuthentication.

            The cardholder authentication value. Also known as Cardholder Authentication Verification Value (CAVV).

        :param authentication_value: The authentication_value of this CardholderAuthentication.
        :type: str
        """

        self._authentication_value = authentication_value
    
    @property
    def electronic_commerce_indicator(self):
        """Gets the electronic_commerce_indicator of this CardholderAuthentication.

            The Electronic Commerce Indicator (ECI) value. The ECI is returned by authentication system and indicates the outcome/status of authentication.

        :return: The electronic_commerce_indicator of this CardholderAuthentication.
        :rtype: str
        """
        return self._electronic_commerce_indicator

    @electronic_commerce_indicator.setter
    def electronic_commerce_indicator(self, electronic_commerce_indicator):
        """Sets the electronic_commerce_indicator of this CardholderAuthentication.

            The Electronic Commerce Indicator (ECI) value. The ECI is returned by authentication system and indicates the outcome/status of authentication.

        :param electronic_commerce_indicator: The electronic_commerce_indicator of this CardholderAuthentication.
        :type: str
        """

        self._electronic_commerce_indicator = electronic_commerce_indicator
    
    @property
    def version(self):
        """Gets the version of this CardholderAuthentication.

            

        :return: The version of this CardholderAuthentication.
        :rtype: CardAuthenticationVersion
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this CardholderAuthentication.

            

        :param version: The version of this CardholderAuthentication.
        :type: CardAuthenticationVersion
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(CardholderAuthentication, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, CardholderAuthentication):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class Transaction:

    swagger_types = {
    
        'accept_header': 'str',
        'accept_language_header': 'str',
        'allowed_payment_method_brands': 'list[int]',
        'allowed_payment_method_configurations': 'list[int]',
        'authorization_amount': 'float',
        'authorization_environment': 'ChargeAttemptEnvironment',
        'authorization_sales_channel': 'int',
        'authorization_timeout_on': 'datetime',
        'authorized_on': 'datetime',
        'auto_confirmation_enabled': 'bool',
        'billing_address': 'Address',
        'charge_retry_enabled': 'bool',
        'completed_amount': 'float',
        'completed_on': 'datetime',
        'completion_behavior': 'TransactionCompletionBehavior',
        'completion_timeout_on': 'datetime',
        'confirmed_by': 'int',
        'confirmed_on': 'datetime',
        'created_by': 'int',
        'created_on': 'datetime',
        'currency': 'str',
        'customer_email_address': 'str',
        'customer_id': 'str',
        'customers_presence': 'CustomersPresence',
        'delivery_decision_made_on': 'datetime',
        'device_session_identifier': 'str',
        'emails_disabled': 'bool',
        'end_of_life': 'datetime',
        'environment': 'Environment',
        'environment_selection_strategy': 'TransactionEnvironmentSelectionStrategy',
        'failed_on': 'datetime',
        'failed_url': 'str',
        'failure_reason': 'FailureReason',
        'group': 'TransactionGroup',
        'id': 'int',
        'internet_protocol_address': 'str',
        'internet_protocol_address_country': 'str',
        'invoice_merchant_reference': 'str',
        'java_enabled': 'bool',
        'language': 'str',
        'line_items': 'list[LineItem]',
        'linked_space_id': 'int',
        'merchant_reference': 'str',
        'meta_data': 'dict(str, str)',
        'parent': 'int',
        'payment_connector_configuration': 'PaymentConnectorConfiguration',
        'planned_purge_date': 'datetime',
        'processing_on': 'datetime',
        'refunded_amount': 'float',
        'screen_color_depth': 'str',
        'screen_height': 'str',
        'screen_width': 'str',
        'shipping_address': 'Address',
        'shipping_method': 'str',
        'space_view_id': 'int',
        'state': 'TransactionState',
        'success_url': 'str',
        'terminal': 'PaymentTerminal',
        'time_zone': 'str',
        'token': 'Token',
        'tokenization_mode': 'TokenizationMode',
        'total_applied_fees': 'float',
        'total_settled_amount': 'float',
        'user_agent_header': 'str',
        'user_failure_message': 'str',
        'user_interface_type': 'TransactionUserInterfaceType',
        'version': 'int',
        'window_height': 'str',
        'window_width': 'str',
        'years_to_keep': 'int',
    }

    attribute_map = {
        'accept_header': 'acceptHeader','accept_language_header': 'acceptLanguageHeader','allowed_payment_method_brands': 'allowedPaymentMethodBrands','allowed_payment_method_configurations': 'allowedPaymentMethodConfigurations','authorization_amount': 'authorizationAmount','authorization_environment': 'authorizationEnvironment','authorization_sales_channel': 'authorizationSalesChannel','authorization_timeout_on': 'authorizationTimeoutOn','authorized_on': 'authorizedOn','auto_confirmation_enabled': 'autoConfirmationEnabled','billing_address': 'billingAddress','charge_retry_enabled': 'chargeRetryEnabled','completed_amount': 'completedAmount','completed_on': 'completedOn','completion_behavior': 'completionBehavior','completion_timeout_on': 'completionTimeoutOn','confirmed_by': 'confirmedBy','confirmed_on': 'confirmedOn','created_by': 'createdBy','created_on': 'createdOn','currency': 'currency','customer_email_address': 'customerEmailAddress','customer_id': 'customerId','customers_presence': 'customersPresence','delivery_decision_made_on': 'deliveryDecisionMadeOn','device_session_identifier': 'deviceSessionIdentifier','emails_disabled': 'emailsDisabled','end_of_life': 'endOfLife','environment': 'environment','environment_selection_strategy': 'environmentSelectionStrategy','failed_on': 'failedOn','failed_url': 'failedUrl','failure_reason': 'failureReason','group': 'group','id': 'id','internet_protocol_address': 'internetProtocolAddress','internet_protocol_address_country': 'internetProtocolAddressCountry','invoice_merchant_reference': 'invoiceMerchantReference','java_enabled': 'javaEnabled','language': 'language','line_items': 'lineItems','linked_space_id': 'linkedSpaceId','merchant_reference': 'merchantReference','meta_data': 'metaData','parent': 'parent','payment_connector_configuration': 'paymentConnectorConfiguration','planned_purge_date': 'plannedPurgeDate','processing_on': 'processingOn','refunded_amount': 'refundedAmount','screen_color_depth': 'screenColorDepth','screen_height': 'screenHeight','screen_width': 'screenWidth','shipping_address': 'shippingAddress','shipping_method': 'shippingMethod','space_view_id': 'spaceViewId','state': 'state','success_url': 'successUrl','terminal': 'terminal','time_zone': 'timeZone','token': 'token','tokenization_mode': 'tokenizationMode','total_applied_fees': 'totalAppliedFees','total_settled_amount': 'totalSettledAmount','user_agent_header': 'userAgentHeader','user_failure_message': 'userFailureMessage','user_interface_type': 'userInterfaceType','version': 'version','window_height': 'windowHeight','window_width': 'windowWidth','years_to_keep': 'yearsToKeep',
    }

    
    _accept_header = None
    _accept_language_header = None
    _allowed_payment_method_brands = None
    _allowed_payment_method_configurations = None
    _authorization_amount = None
    _authorization_environment = None
    _authorization_sales_channel = None
    _authorization_timeout_on = None
    _authorized_on = None
    _auto_confirmation_enabled = None
    _billing_address = None
    _charge_retry_enabled = None
    _completed_amount = None
    _completed_on = None
    _completion_behavior = None
    _completion_timeout_on = None
    _confirmed_by = None
    _confirmed_on = None
    _created_by = None
    _created_on = None
    _currency = None
    _customer_email_address = None
    _customer_id = None
    _customers_presence = None
    _delivery_decision_made_on = None
    _device_session_identifier = None
    _emails_disabled = None
    _end_of_life = None
    _environment = None
    _environment_selection_strategy = None
    _failed_on = None
    _failed_url = None
    _failure_reason = None
    _group = None
    _id = None
    _internet_protocol_address = None
    _internet_protocol_address_country = None
    _invoice_merchant_reference = None
    _java_enabled = None
    _language = None
    _line_items = None
    _linked_space_id = None
    _merchant_reference = None
    _meta_data = None
    _parent = None
    _payment_connector_configuration = None
    _planned_purge_date = None
    _processing_on = None
    _refunded_amount = None
    _screen_color_depth = None
    _screen_height = None
    _screen_width = None
    _shipping_address = None
    _shipping_method = None
    _space_view_id = None
    _state = None
    _success_url = None
    _terminal = None
    _time_zone = None
    _token = None
    _tokenization_mode = None
    _total_applied_fees = None
    _total_settled_amount = None
    _user_agent_header = None
    _user_failure_message = None
    _user_interface_type = None
    _version = None
    _window_height = None
    _window_width = None
    _years_to_keep = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.accept_header = kwargs.get('accept_header', None)
        self.accept_language_header = kwargs.get('accept_language_header', None)
        self.allowed_payment_method_brands = kwargs.get('allowed_payment_method_brands', None)
        self.allowed_payment_method_configurations = kwargs.get('allowed_payment_method_configurations', None)
        self.authorization_amount = kwargs.get('authorization_amount', None)
        self.authorization_environment = kwargs.get('authorization_environment', None)
        self.authorization_sales_channel = kwargs.get('authorization_sales_channel', None)
        self.authorization_timeout_on = kwargs.get('authorization_timeout_on', None)
        self.authorized_on = kwargs.get('authorized_on', None)
        self.auto_confirmation_enabled = kwargs.get('auto_confirmation_enabled', None)
        self.billing_address = kwargs.get('billing_address', None)
        self.charge_retry_enabled = kwargs.get('charge_retry_enabled', None)
        self.completed_amount = kwargs.get('completed_amount', None)
        self.completed_on = kwargs.get('completed_on', None)
        self.completion_behavior = kwargs.get('completion_behavior', None)
        self.completion_timeout_on = kwargs.get('completion_timeout_on', None)
        self.confirmed_by = kwargs.get('confirmed_by', None)
        self.confirmed_on = kwargs.get('confirmed_on', None)
        self.created_by = kwargs.get('created_by', None)
        self.created_on = kwargs.get('created_on', None)
        self.currency = kwargs.get('currency', None)
        self.customer_email_address = kwargs.get('customer_email_address', None)
        self.customer_id = kwargs.get('customer_id', None)
        self.customers_presence = kwargs.get('customers_presence', None)
        self.delivery_decision_made_on = kwargs.get('delivery_decision_made_on', None)
        self.device_session_identifier = kwargs.get('device_session_identifier', None)
        self.emails_disabled = kwargs.get('emails_disabled', None)
        self.end_of_life = kwargs.get('end_of_life', None)
        self.environment = kwargs.get('environment', None)
        self.environment_selection_strategy = kwargs.get('environment_selection_strategy', None)
        self.failed_on = kwargs.get('failed_on', None)
        self.failed_url = kwargs.get('failed_url', None)
        self.failure_reason = kwargs.get('failure_reason', None)
        self.group = kwargs.get('group', None)
        self.id = kwargs.get('id', None)
        self.internet_protocol_address = kwargs.get('internet_protocol_address', None)
        self.internet_protocol_address_country = kwargs.get('internet_protocol_address_country', None)
        self.invoice_merchant_reference = kwargs.get('invoice_merchant_reference', None)
        self.java_enabled = kwargs.get('java_enabled', None)
        self.language = kwargs.get('language', None)
        self.line_items = kwargs.get('line_items', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.merchant_reference = kwargs.get('merchant_reference', None)
        self.meta_data = kwargs.get('meta_data', None)
        self.parent = kwargs.get('parent', None)
        self.payment_connector_configuration = kwargs.get('payment_connector_configuration', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.processing_on = kwargs.get('processing_on', None)
        self.refunded_amount = kwargs.get('refunded_amount', None)
        self.screen_color_depth = kwargs.get('screen_color_depth', None)
        self.screen_height = kwargs.get('screen_height', None)
        self.screen_width = kwargs.get('screen_width', None)
        self.shipping_address = kwargs.get('shipping_address', None)
        self.shipping_method = kwargs.get('shipping_method', None)
        self.space_view_id = kwargs.get('space_view_id', None)
        self.state = kwargs.get('state', None)
        self.success_url = kwargs.get('success_url', None)
        self.terminal = kwargs.get('terminal', None)
        self.time_zone = kwargs.get('time_zone', None)
        self.token = kwargs.get('token', None)
        self.tokenization_mode = kwargs.get('tokenization_mode', None)
        self.total_applied_fees = kwargs.get('total_applied_fees', None)
        self.total_settled_amount = kwargs.get('total_settled_amount', None)
        self.user_agent_header = kwargs.get('user_agent_header', None)
        self.user_failure_message = kwargs.get('user_failure_message', None)
        self.user_interface_type = kwargs.get('user_interface_type', None)
        self.version = kwargs.get('version', None)
        self.window_height = kwargs.get('window_height', None)
        self.window_width = kwargs.get('window_width', None)
        self.years_to_keep = kwargs.get('years_to_keep', None)
        

    
    @property
    def accept_header(self):
        """Gets the accept_header of this Transaction.

            

        :return: The accept_header of this Transaction.
        :rtype: str
        """
        return self._accept_header

    @accept_header.setter
    def accept_header(self, accept_header):
        """Sets the accept_header of this Transaction.

            

        :param accept_header: The accept_header of this Transaction.
        :type: str
        """

        self._accept_header = accept_header
    
    @property
    def accept_language_header(self):
        """Gets the accept_language_header of this Transaction.

            The accept language contains the header which indicates the language preferences of the buyer.

        :return: The accept_language_header of this Transaction.
        :rtype: str
        """
        return self._accept_language_header

    @accept_language_header.setter
    def accept_language_header(self, accept_language_header):
        """Sets the accept_language_header of this Transaction.

            The accept language contains the header which indicates the language preferences of the buyer.

        :param accept_language_header: The accept_language_header of this Transaction.
        :type: str
        """

        self._accept_language_header = accept_language_header
    
    @property
    def allowed_payment_method_brands(self):
        """Gets the allowed_payment_method_brands of this Transaction.

            

        :return: The allowed_payment_method_brands of this Transaction.
        :rtype: list[int]
        """
        return self._allowed_payment_method_brands

    @allowed_payment_method_brands.setter
    def allowed_payment_method_brands(self, allowed_payment_method_brands):
        """Sets the allowed_payment_method_brands of this Transaction.

            

        :param allowed_payment_method_brands: The allowed_payment_method_brands of this Transaction.
        :type: list[int]
        """

        self._allowed_payment_method_brands = allowed_payment_method_brands
    
    @property
    def allowed_payment_method_configurations(self):
        """Gets the allowed_payment_method_configurations of this Transaction.

            

        :return: The allowed_payment_method_configurations of this Transaction.
        :rtype: list[int]
        """
        return self._allowed_payment_method_configurations

    @allowed_payment_method_configurations.setter
    def allowed_payment_method_configurations(self, allowed_payment_method_configurations):
        """Sets the allowed_payment_method_configurations of this Transaction.

            

        :param allowed_payment_method_configurations: The allowed_payment_method_configurations of this Transaction.
        :type: list[int]
        """

        self._allowed_payment_method_configurations = allowed_payment_method_configurations
    
    @property
    def authorization_amount(self):
        """Gets the authorization_amount of this Transaction.

            

        :return: The authorization_amount of this Transaction.
        :rtype: float
        """
        return self._authorization_amount

    @authorization_amount.setter
    def authorization_amount(self, authorization_amount):
        """Sets the authorization_amount of this Transaction.

            

        :param authorization_amount: The authorization_amount of this Transaction.
        :type: float
        """

        self._authorization_amount = authorization_amount
    
    @property
    def authorization_environment(self):
        """Gets the authorization_environment of this Transaction.

            The environment in which this transaction was successfully authorized.

        :return: The authorization_environment of this Transaction.
        :rtype: ChargeAttemptEnvironment
        """
        return self._authorization_environment

    @authorization_environment.setter
    def authorization_environment(self, authorization_environment):
        """Sets the authorization_environment of this Transaction.

            The environment in which this transaction was successfully authorized.

        :param authorization_environment: The authorization_environment of this Transaction.
        :type: ChargeAttemptEnvironment
        """

        self._authorization_environment = authorization_environment
    
    @property
    def authorization_sales_channel(self):
        """Gets the authorization_sales_channel of this Transaction.

            The sales channel through which the transaction was placed.

        :return: The authorization_sales_channel of this Transaction.
        :rtype: int
        """
        return self._authorization_sales_channel

    @authorization_sales_channel.setter
    def authorization_sales_channel(self, authorization_sales_channel):
        """Sets the authorization_sales_channel of this Transaction.

            The sales channel through which the transaction was placed.

        :param authorization_sales_channel: The authorization_sales_channel of this Transaction.
        :type: int
        """

        self._authorization_sales_channel = authorization_sales_channel
    
    @property
    def authorization_timeout_on(self):
        """Gets the authorization_timeout_on of this Transaction.

            This is the time on which the transaction will be timed out when it is not at least authorized. The timeout time may change over time.

        :return: The authorization_timeout_on of this Transaction.
        :rtype: datetime
        """
        return self._authorization_timeout_on

    @authorization_timeout_on.setter
    def authorization_timeout_on(self, authorization_timeout_on):
        """Sets the authorization_timeout_on of this Transaction.

            This is the time on which the transaction will be timed out when it is not at least authorized. The timeout time may change over time.

        :param authorization_timeout_on: The authorization_timeout_on of this Transaction.
        :type: datetime
        """

        self._authorization_timeout_on = authorization_timeout_on
    
    @property
    def authorized_on(self):
        """Gets the authorized_on of this Transaction.

            

        :return: The authorized_on of this Transaction.
        :rtype: datetime
        """
        return self._authorized_on

    @authorized_on.setter
    def authorized_on(self, authorized_on):
        """Sets the authorized_on of this Transaction.

            

        :param authorized_on: The authorized_on of this Transaction.
        :type: datetime
        """

        self._authorized_on = authorized_on
    
    @property
    def auto_confirmation_enabled(self):
        """Gets the auto_confirmation_enabled of this Transaction.

            When auto confirmation is enabled the transaction can be confirmed by the user and does not require an explicit confirmation through the web service API.

        :return: The auto_confirmation_enabled of this Transaction.
        :rtype: bool
        """
        return self._auto_confirmation_enabled

    @auto_confirmation_enabled.setter
    def auto_confirmation_enabled(self, auto_confirmation_enabled):
        """Sets the auto_confirmation_enabled of this Transaction.

            When auto confirmation is enabled the transaction can be confirmed by the user and does not require an explicit confirmation through the web service API.

        :param auto_confirmation_enabled: The auto_confirmation_enabled of this Transaction.
        :type: bool
        """

        self._auto_confirmation_enabled = auto_confirmation_enabled
    
    @property
    def billing_address(self):
        """Gets the billing_address of this Transaction.

            

        :return: The billing_address of this Transaction.
        :rtype: Address
        """
        return self._billing_address

    @billing_address.setter
    def billing_address(self, billing_address):
        """Sets the billing_address of this Transaction.

            

        :param billing_address: The billing_address of this Transaction.
        :type: Address
        """

        self._billing_address = billing_address
    
    @property
    def charge_retry_enabled(self):
        """Gets the charge_retry_enabled of this Transaction.

            When the charging of the customer fails we can retry the charging. This implies that we redirect the user back to the payment page which allows the customer to retry. By default we will retry.

        :return: The charge_retry_enabled of this Transaction.
        :rtype: bool
        """
        return self._charge_retry_enabled

    @charge_retry_enabled.setter
    def charge_retry_enabled(self, charge_retry_enabled):
        """Sets the charge_retry_enabled of this Transaction.

            When the charging of the customer fails we can retry the charging. This implies that we redirect the user back to the payment page which allows the customer to retry. By default we will retry.

        :param charge_retry_enabled: The charge_retry_enabled of this Transaction.
        :type: bool
        """

        self._charge_retry_enabled = charge_retry_enabled
    
    @property
    def completed_amount(self):
        """Gets the completed_amount of this Transaction.

            The completed amount is the total amount which has been captured so far.

        :return: The completed_amount of this Transaction.
        :rtype: float
        """
        return self._completed_amount

    @completed_amount.setter
    def completed_amount(self, completed_amount):
        """Sets the completed_amount of this Transaction.

            The completed amount is the total amount which has been captured so far.

        :param completed_amount: The completed_amount of this Transaction.
        :type: float
        """

        self._completed_amount = completed_amount
    
    @property
    def completed_on(self):
        """Gets the completed_on of this Transaction.

            

        :return: The completed_on of this Transaction.
        :rtype: datetime
        """
        return self._completed_on

    @completed_on.setter
    def completed_on(self, completed_on):
        """Sets the completed_on of this Transaction.

            

        :param completed_on: The completed_on of this Transaction.
        :type: datetime
        """

        self._completed_on = completed_on
    
    @property
    def completion_behavior(self):
        """Gets the completion_behavior of this Transaction.

            The completion behavior controls when the transaction is completed.

        :return: The completion_behavior of this Transaction.
        :rtype: TransactionCompletionBehavior
        """
        return self._completion_behavior

    @completion_behavior.setter
    def completion_behavior(self, completion_behavior):
        """Sets the completion_behavior of this Transaction.

            The completion behavior controls when the transaction is completed.

        :param completion_behavior: The completion_behavior of this Transaction.
        :type: TransactionCompletionBehavior
        """

        self._completion_behavior = completion_behavior
    
    @property
    def completion_timeout_on(self):
        """Gets the completion_timeout_on of this Transaction.

            

        :return: The completion_timeout_on of this Transaction.
        :rtype: datetime
        """
        return self._completion_timeout_on

    @completion_timeout_on.setter
    def completion_timeout_on(self, completion_timeout_on):
        """Sets the completion_timeout_on of this Transaction.

            

        :param completion_timeout_on: The completion_timeout_on of this Transaction.
        :type: datetime
        """

        self._completion_timeout_on = completion_timeout_on
    
    @property
    def confirmed_by(self):
        """Gets the confirmed_by of this Transaction.

            

        :return: The confirmed_by of this Transaction.
        :rtype: int
        """
        return self._confirmed_by

    @confirmed_by.setter
    def confirmed_by(self, confirmed_by):
        """Sets the confirmed_by of this Transaction.

            

        :param confirmed_by: The confirmed_by of this Transaction.
        :type: int
        """

        self._confirmed_by = confirmed_by
    
    @property
    def confirmed_on(self):
        """Gets the confirmed_on of this Transaction.

            

        :return: The confirmed_on of this Transaction.
        :rtype: datetime
        """
        return self._confirmed_on

    @confirmed_on.setter
    def confirmed_on(self, confirmed_on):
        """Sets the confirmed_on of this Transaction.

            

        :param confirmed_on: The confirmed_on of this Transaction.
        :type: datetime
        """

        self._confirmed_on = confirmed_on
    
    @property
    def created_by(self):
        """Gets the created_by of this Transaction.

            

        :return: The created_by of this Transaction.
        :rtype: int
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this Transaction.

            

        :param created_by: The created_by of this Transaction.
        :type: int
        """

        self._created_by = created_by
    
    @property
    def created_on(self):
        """Gets the created_on of this Transaction.

            The date and time when the object was created.

        :return: The created_on of this Transaction.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this Transaction.

            The date and time when the object was created.

        :param created_on: The created_on of this Transaction.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def currency(self):
        """Gets the currency of this Transaction.

            

        :return: The currency of this Transaction.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this Transaction.

            

        :param currency: The currency of this Transaction.
        :type: str
        """

        self._currency = currency
    
    @property
    def customer_email_address(self):
        """Gets the customer_email_address of this Transaction.

            The customer email address is the email address of the customer. If no email address is provided on the shipping or billing address this address is used.

        :return: The customer_email_address of this Transaction.
        :rtype: str
        """
        return self._customer_email_address

    @customer_email_address.setter
    def customer_email_address(self, customer_email_address):
        """Sets the customer_email_address of this Transaction.

            The customer email address is the email address of the customer. If no email address is provided on the shipping or billing address this address is used.

        :param customer_email_address: The customer_email_address of this Transaction.
        :type: str
        """
        if customer_email_address is not None and len(customer_email_address) > 254:
            raise ValueError("Invalid value for `customer_email_address`, length must be less than or equal to `254`")

        self._customer_email_address = customer_email_address
    
    @property
    def customer_id(self):
        """Gets the customer_id of this Transaction.

            

        :return: The customer_id of this Transaction.
        :rtype: str
        """
        return self._customer_id

    @customer_id.setter
    def customer_id(self, customer_id):
        """Sets the customer_id of this Transaction.

            

        :param customer_id: The customer_id of this Transaction.
        :type: str
        """

        self._customer_id = customer_id
    
    @property
    def customers_presence(self):
        """Gets the customers_presence of this Transaction.

            The customer's presence indicates what kind of authentication method was finally used during authorization of the transaction. If no value is provided, 'Virtually Present' is used by default.

        :return: The customers_presence of this Transaction.
        :rtype: CustomersPresence
        """
        return self._customers_presence

    @customers_presence.setter
    def customers_presence(self, customers_presence):
        """Sets the customers_presence of this Transaction.

            The customer's presence indicates what kind of authentication method was finally used during authorization of the transaction. If no value is provided, 'Virtually Present' is used by default.

        :param customers_presence: The customers_presence of this Transaction.
        :type: CustomersPresence
        """

        self._customers_presence = customers_presence
    
    @property
    def delivery_decision_made_on(self):
        """Gets the delivery_decision_made_on of this Transaction.

            This date indicates when the decision has been made if a transaction should be delivered or not.

        :return: The delivery_decision_made_on of this Transaction.
        :rtype: datetime
        """
        return self._delivery_decision_made_on

    @delivery_decision_made_on.setter
    def delivery_decision_made_on(self, delivery_decision_made_on):
        """Sets the delivery_decision_made_on of this Transaction.

            This date indicates when the decision has been made if a transaction should be delivered or not.

        :param delivery_decision_made_on: The delivery_decision_made_on of this Transaction.
        :type: datetime
        """

        self._delivery_decision_made_on = delivery_decision_made_on
    
    @property
    def device_session_identifier(self):
        """Gets the device_session_identifier of this Transaction.

            The device session identifier links the transaction with the session identifier provided in the URL of the device data JavaScript. This allows to link the transaction with the collected device data of the buyer.

        :return: The device_session_identifier of this Transaction.
        :rtype: str
        """
        return self._device_session_identifier

    @device_session_identifier.setter
    def device_session_identifier(self, device_session_identifier):
        """Sets the device_session_identifier of this Transaction.

            The device session identifier links the transaction with the session identifier provided in the URL of the device data JavaScript. This allows to link the transaction with the collected device data of the buyer.

        :param device_session_identifier: The device_session_identifier of this Transaction.
        :type: str
        """
        if device_session_identifier is not None and len(device_session_identifier) > 40:
            raise ValueError("Invalid value for `device_session_identifier`, length must be less than or equal to `40`")
        if device_session_identifier is not None and len(device_session_identifier) < 10:
            raise ValueError("Invalid value for `device_session_identifier`, length must be greater than or equal to `10`")

        self._device_session_identifier = device_session_identifier
    
    @property
    def emails_disabled(self):
        """Gets the emails_disabled of this Transaction.

            Flag indicating whether email sending is disabled for this particular transaction. Defaults to false.

        :return: The emails_disabled of this Transaction.
        :rtype: bool
        """
        return self._emails_disabled

    @emails_disabled.setter
    def emails_disabled(self, emails_disabled):
        """Sets the emails_disabled of this Transaction.

            Flag indicating whether email sending is disabled for this particular transaction. Defaults to false.

        :param emails_disabled: The emails_disabled of this Transaction.
        :type: bool
        """

        self._emails_disabled = emails_disabled
    
    @property
    def end_of_life(self):
        """Gets the end_of_life of this Transaction.

            The transaction's end of life indicates the date from which on no operation can be carried out anymore.

        :return: The end_of_life of this Transaction.
        :rtype: datetime
        """
        return self._end_of_life

    @end_of_life.setter
    def end_of_life(self, end_of_life):
        """Sets the end_of_life of this Transaction.

            The transaction's end of life indicates the date from which on no operation can be carried out anymore.

        :param end_of_life: The end_of_life of this Transaction.
        :type: datetime
        """

        self._end_of_life = end_of_life
    
    @property
    def environment(self):
        """Gets the environment of this Transaction.

            

        :return: The environment of this Transaction.
        :rtype: Environment
        """
        return self._environment

    @environment.setter
    def environment(self, environment):
        """Sets the environment of this Transaction.

            

        :param environment: The environment of this Transaction.
        :type: Environment
        """

        self._environment = environment
    
    @property
    def environment_selection_strategy(self):
        """Gets the environment_selection_strategy of this Transaction.

            The environment selection strategy determines how the environment (test or production) for processing the transaction is selected.

        :return: The environment_selection_strategy of this Transaction.
        :rtype: TransactionEnvironmentSelectionStrategy
        """
        return self._environment_selection_strategy

    @environment_selection_strategy.setter
    def environment_selection_strategy(self, environment_selection_strategy):
        """Sets the environment_selection_strategy of this Transaction.

            The environment selection strategy determines how the environment (test or production) for processing the transaction is selected.

        :param environment_selection_strategy: The environment_selection_strategy of this Transaction.
        :type: TransactionEnvironmentSelectionStrategy
        """

        self._environment_selection_strategy = environment_selection_strategy
    
    @property
    def failed_on(self):
        """Gets the failed_on of this Transaction.

            

        :return: The failed_on of this Transaction.
        :rtype: datetime
        """
        return self._failed_on

    @failed_on.setter
    def failed_on(self, failed_on):
        """Sets the failed_on of this Transaction.

            

        :param failed_on: The failed_on of this Transaction.
        :type: datetime
        """

        self._failed_on = failed_on
    
    @property
    def failed_url(self):
        """Gets the failed_url of this Transaction.

            The user will be redirected to failed URL when the transaction could not be authorized or completed. In case no failed URL is specified a default failed page will be displayed.

        :return: The failed_url of this Transaction.
        :rtype: str
        """
        return self._failed_url

    @failed_url.setter
    def failed_url(self, failed_url):
        """Sets the failed_url of this Transaction.

            The user will be redirected to failed URL when the transaction could not be authorized or completed. In case no failed URL is specified a default failed page will be displayed.

        :param failed_url: The failed_url of this Transaction.
        :type: str
        """
        if failed_url is not None and len(failed_url) > 2000:
            raise ValueError("Invalid value for `failed_url`, length must be less than or equal to `2000`")
        if failed_url is not None and len(failed_url) < 9:
            raise ValueError("Invalid value for `failed_url`, length must be greater than or equal to `9`")

        self._failed_url = failed_url
    
    @property
    def failure_reason(self):
        """Gets the failure_reason of this Transaction.

            The failure reason describes why the transaction failed. This is only provided when the transaction is marked as failed.

        :return: The failure_reason of this Transaction.
        :rtype: FailureReason
        """
        return self._failure_reason

    @failure_reason.setter
    def failure_reason(self, failure_reason):
        """Sets the failure_reason of this Transaction.

            The failure reason describes why the transaction failed. This is only provided when the transaction is marked as failed.

        :param failure_reason: The failure_reason of this Transaction.
        :type: FailureReason
        """

        self._failure_reason = failure_reason
    
    @property
    def group(self):
        """Gets the group of this Transaction.

            

        :return: The group of this Transaction.
        :rtype: TransactionGroup
        """
        return self._group

    @group.setter
    def group(self, group):
        """Sets the group of this Transaction.

            

        :param group: The group of this Transaction.
        :type: TransactionGroup
        """

        self._group = group
    
    @property
    def id(self):
        """Gets the id of this Transaction.

            A unique identifier for the object.

        :return: The id of this Transaction.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Transaction.

            A unique identifier for the object.

        :param id: The id of this Transaction.
        :type: int
        """

        self._id = id
    
    @property
    def internet_protocol_address(self):
        """Gets the internet_protocol_address of this Transaction.

            The Internet Protocol (IP) address identifies the device of the buyer.

        :return: The internet_protocol_address of this Transaction.
        :rtype: str
        """
        return self._internet_protocol_address

    @internet_protocol_address.setter
    def internet_protocol_address(self, internet_protocol_address):
        """Sets the internet_protocol_address of this Transaction.

            The Internet Protocol (IP) address identifies the device of the buyer.

        :param internet_protocol_address: The internet_protocol_address of this Transaction.
        :type: str
        """

        self._internet_protocol_address = internet_protocol_address
    
    @property
    def internet_protocol_address_country(self):
        """Gets the internet_protocol_address_country of this Transaction.

            

        :return: The internet_protocol_address_country of this Transaction.
        :rtype: str
        """
        return self._internet_protocol_address_country

    @internet_protocol_address_country.setter
    def internet_protocol_address_country(self, internet_protocol_address_country):
        """Sets the internet_protocol_address_country of this Transaction.

            

        :param internet_protocol_address_country: The internet_protocol_address_country of this Transaction.
        :type: str
        """

        self._internet_protocol_address_country = internet_protocol_address_country
    
    @property
    def invoice_merchant_reference(self):
        """Gets the invoice_merchant_reference of this Transaction.

            

        :return: The invoice_merchant_reference of this Transaction.
        :rtype: str
        """
        return self._invoice_merchant_reference

    @invoice_merchant_reference.setter
    def invoice_merchant_reference(self, invoice_merchant_reference):
        """Sets the invoice_merchant_reference of this Transaction.

            

        :param invoice_merchant_reference: The invoice_merchant_reference of this Transaction.
        :type: str
        """
        if invoice_merchant_reference is not None and len(invoice_merchant_reference) > 100:
            raise ValueError("Invalid value for `invoice_merchant_reference`, length must be less than or equal to `100`")

        self._invoice_merchant_reference = invoice_merchant_reference
    
    @property
    def java_enabled(self):
        """Gets the java_enabled of this Transaction.

            

        :return: The java_enabled of this Transaction.
        :rtype: bool
        """
        return self._java_enabled

    @java_enabled.setter
    def java_enabled(self, java_enabled):
        """Sets the java_enabled of this Transaction.

            

        :param java_enabled: The java_enabled of this Transaction.
        :type: bool
        """

        self._java_enabled = java_enabled
    
    @property
    def language(self):
        """Gets the language of this Transaction.

            The language that is linked to the object.

        :return: The language of this Transaction.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this Transaction.

            The language that is linked to the object.

        :param language: The language of this Transaction.
        :type: str
        """

        self._language = language
    
    @property
    def line_items(self):
        """Gets the line_items of this Transaction.

            

        :return: The line_items of this Transaction.
        :rtype: list[LineItem]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """Sets the line_items of this Transaction.

            

        :param line_items: The line_items of this Transaction.
        :type: list[LineItem]
        """

        self._line_items = line_items
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this Transaction.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this Transaction.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this Transaction.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this Transaction.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def merchant_reference(self):
        """Gets the merchant_reference of this Transaction.

            

        :return: The merchant_reference of this Transaction.
        :rtype: str
        """
        return self._merchant_reference

    @merchant_reference.setter
    def merchant_reference(self, merchant_reference):
        """Sets the merchant_reference of this Transaction.

            

        :param merchant_reference: The merchant_reference of this Transaction.
        :type: str
        """
        if merchant_reference is not None and len(merchant_reference) > 100:
            raise ValueError("Invalid value for `merchant_reference`, length must be less than or equal to `100`")

        self._merchant_reference = merchant_reference
    
    @property
    def meta_data(self):
        """Gets the meta_data of this Transaction.

            Allow to store additional information about the object.

        :return: The meta_data of this Transaction.
        :rtype: dict(str, str)
        """
        return self._meta_data

    @meta_data.setter
    def meta_data(self, meta_data):
        """Sets the meta_data of this Transaction.

            Allow to store additional information about the object.

        :param meta_data: The meta_data of this Transaction.
        :type: dict(str, str)
        """

        self._meta_data = meta_data
    
    @property
    def parent(self):
        """Gets the parent of this Transaction.

            

        :return: The parent of this Transaction.
        :rtype: int
        """
        return self._parent

    @parent.setter
    def parent(self, parent):
        """Sets the parent of this Transaction.

            

        :param parent: The parent of this Transaction.
        :type: int
        """

        self._parent = parent
    
    @property
    def payment_connector_configuration(self):
        """Gets the payment_connector_configuration of this Transaction.

            

        :return: The payment_connector_configuration of this Transaction.
        :rtype: PaymentConnectorConfiguration
        """
        return self._payment_connector_configuration

    @payment_connector_configuration.setter
    def payment_connector_configuration(self, payment_connector_configuration):
        """Sets the payment_connector_configuration of this Transaction.

            

        :param payment_connector_configuration: The payment_connector_configuration of this Transaction.
        :type: PaymentConnectorConfiguration
        """

        self._payment_connector_configuration = payment_connector_configuration
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this Transaction.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this Transaction.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this Transaction.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this Transaction.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def processing_on(self):
        """Gets the processing_on of this Transaction.

            

        :return: The processing_on of this Transaction.
        :rtype: datetime
        """
        return self._processing_on

    @processing_on.setter
    def processing_on(self, processing_on):
        """Sets the processing_on of this Transaction.

            

        :param processing_on: The processing_on of this Transaction.
        :type: datetime
        """

        self._processing_on = processing_on
    
    @property
    def refunded_amount(self):
        """Gets the refunded_amount of this Transaction.

            The refunded amount is the total amount which has been refunded so far.

        :return: The refunded_amount of this Transaction.
        :rtype: float
        """
        return self._refunded_amount

    @refunded_amount.setter
    def refunded_amount(self, refunded_amount):
        """Sets the refunded_amount of this Transaction.

            The refunded amount is the total amount which has been refunded so far.

        :param refunded_amount: The refunded_amount of this Transaction.
        :type: float
        """

        self._refunded_amount = refunded_amount
    
    @property
    def screen_color_depth(self):
        """Gets the screen_color_depth of this Transaction.

            

        :return: The screen_color_depth of this Transaction.
        :rtype: str
        """
        return self._screen_color_depth

    @screen_color_depth.setter
    def screen_color_depth(self, screen_color_depth):
        """Sets the screen_color_depth of this Transaction.

            

        :param screen_color_depth: The screen_color_depth of this Transaction.
        :type: str
        """

        self._screen_color_depth = screen_color_depth
    
    @property
    def screen_height(self):
        """Gets the screen_height of this Transaction.

            

        :return: The screen_height of this Transaction.
        :rtype: str
        """
        return self._screen_height

    @screen_height.setter
    def screen_height(self, screen_height):
        """Sets the screen_height of this Transaction.

            

        :param screen_height: The screen_height of this Transaction.
        :type: str
        """

        self._screen_height = screen_height
    
    @property
    def screen_width(self):
        """Gets the screen_width of this Transaction.

            

        :return: The screen_width of this Transaction.
        :rtype: str
        """
        return self._screen_width

    @screen_width.setter
    def screen_width(self, screen_width):
        """Sets the screen_width of this Transaction.

            

        :param screen_width: The screen_width of this Transaction.
        :type: str
        """

        self._screen_width = screen_width
    
    @property
    def shipping_address(self):
        """Gets the shipping_address of this Transaction.

            

        :return: The shipping_address of this Transaction.
        :rtype: Address
        """
        return self._shipping_address

    @shipping_address.setter
    def shipping_address(self, shipping_address):
        """Sets the shipping_address of this Transaction.

            

        :param shipping_address: The shipping_address of this Transaction.
        :type: Address
        """

        self._shipping_address = shipping_address
    
    @property
    def shipping_method(self):
        """Gets the shipping_method of this Transaction.

            

        :return: The shipping_method of this Transaction.
        :rtype: str
        """
        return self._shipping_method

    @shipping_method.setter
    def shipping_method(self, shipping_method):
        """Sets the shipping_method of this Transaction.

            

        :param shipping_method: The shipping_method of this Transaction.
        :type: str
        """
        if shipping_method is not None and len(shipping_method) > 200:
            raise ValueError("Invalid value for `shipping_method`, length must be less than or equal to `200`")

        self._shipping_method = shipping_method
    
    @property
    def space_view_id(self):
        """Gets the space_view_id of this Transaction.

            

        :return: The space_view_id of this Transaction.
        :rtype: int
        """
        return self._space_view_id

    @space_view_id.setter
    def space_view_id(self, space_view_id):
        """Sets the space_view_id of this Transaction.

            

        :param space_view_id: The space_view_id of this Transaction.
        :type: int
        """

        self._space_view_id = space_view_id
    
    @property
    def state(self):
        """Gets the state of this Transaction.

            The object's current state.

        :return: The state of this Transaction.
        :rtype: TransactionState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this Transaction.

            The object's current state.

        :param state: The state of this Transaction.
        :type: TransactionState
        """

        self._state = state
    
    @property
    def success_url(self):
        """Gets the success_url of this Transaction.

            The user will be redirected to success URL when the transaction could be authorized or completed. In case no success URL is specified a default success page will be displayed.

        :return: The success_url of this Transaction.
        :rtype: str
        """
        return self._success_url

    @success_url.setter
    def success_url(self, success_url):
        """Sets the success_url of this Transaction.

            The user will be redirected to success URL when the transaction could be authorized or completed. In case no success URL is specified a default success page will be displayed.

        :param success_url: The success_url of this Transaction.
        :type: str
        """
        if success_url is not None and len(success_url) > 2000:
            raise ValueError("Invalid value for `success_url`, length must be less than or equal to `2000`")
        if success_url is not None and len(success_url) < 9:
            raise ValueError("Invalid value for `success_url`, length must be greater than or equal to `9`")

        self._success_url = success_url
    
    @property
    def terminal(self):
        """Gets the terminal of this Transaction.

            The terminal on which the payment was processed.

        :return: The terminal of this Transaction.
        :rtype: PaymentTerminal
        """
        return self._terminal

    @terminal.setter
    def terminal(self, terminal):
        """Sets the terminal of this Transaction.

            The terminal on which the payment was processed.

        :param terminal: The terminal of this Transaction.
        :type: PaymentTerminal
        """

        self._terminal = terminal
    
    @property
    def time_zone(self):
        """Gets the time_zone of this Transaction.

            The time zone defines in which time zone the customer is located in. The time zone may affects how dates are formatted when interacting with the customer.

        :return: The time_zone of this Transaction.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """Sets the time_zone of this Transaction.

            The time zone defines in which time zone the customer is located in. The time zone may affects how dates are formatted when interacting with the customer.

        :param time_zone: The time_zone of this Transaction.
        :type: str
        """

        self._time_zone = time_zone
    
    @property
    def token(self):
        """Gets the token of this Transaction.

            

        :return: The token of this Transaction.
        :rtype: Token
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this Transaction.

            

        :param token: The token of this Transaction.
        :type: Token
        """

        self._token = token
    
    @property
    def tokenization_mode(self):
        """Gets the tokenization_mode of this Transaction.

            The tokenization mode controls if and how the tokenization of payment information is applied to the transaction.

        :return: The tokenization_mode of this Transaction.
        :rtype: TokenizationMode
        """
        return self._tokenization_mode

    @tokenization_mode.setter
    def tokenization_mode(self, tokenization_mode):
        """Sets the tokenization_mode of this Transaction.

            The tokenization mode controls if and how the tokenization of payment information is applied to the transaction.

        :param tokenization_mode: The tokenization_mode of this Transaction.
        :type: TokenizationMode
        """

        self._tokenization_mode = tokenization_mode
    
    @property
    def total_applied_fees(self):
        """Gets the total_applied_fees of this Transaction.

            The total applied fees is the sum of all fees that have been applied so far.

        :return: The total_applied_fees of this Transaction.
        :rtype: float
        """
        return self._total_applied_fees

    @total_applied_fees.setter
    def total_applied_fees(self, total_applied_fees):
        """Sets the total_applied_fees of this Transaction.

            The total applied fees is the sum of all fees that have been applied so far.

        :param total_applied_fees: The total_applied_fees of this Transaction.
        :type: float
        """

        self._total_applied_fees = total_applied_fees
    
    @property
    def total_settled_amount(self):
        """Gets the total_settled_amount of this Transaction.

            The total settled amount is the total amount which has been settled so far.

        :return: The total_settled_amount of this Transaction.
        :rtype: float
        """
        return self._total_settled_amount

    @total_settled_amount.setter
    def total_settled_amount(self, total_settled_amount):
        """Sets the total_settled_amount of this Transaction.

            The total settled amount is the total amount which has been settled so far.

        :param total_settled_amount: The total_settled_amount of this Transaction.
        :type: float
        """

        self._total_settled_amount = total_settled_amount
    
    @property
    def user_agent_header(self):
        """Gets the user_agent_header of this Transaction.

            The user agent header provides the exact string which contains the user agent of the buyer.

        :return: The user_agent_header of this Transaction.
        :rtype: str
        """
        return self._user_agent_header

    @user_agent_header.setter
    def user_agent_header(self, user_agent_header):
        """Sets the user_agent_header of this Transaction.

            The user agent header provides the exact string which contains the user agent of the buyer.

        :param user_agent_header: The user_agent_header of this Transaction.
        :type: str
        """

        self._user_agent_header = user_agent_header
    
    @property
    def user_failure_message(self):
        """Gets the user_failure_message of this Transaction.

            The failure message describes for an end user why the transaction is failed in the language of the user. This is only provided when the transaction is marked as failed.

        :return: The user_failure_message of this Transaction.
        :rtype: str
        """
        return self._user_failure_message

    @user_failure_message.setter
    def user_failure_message(self, user_failure_message):
        """Sets the user_failure_message of this Transaction.

            The failure message describes for an end user why the transaction is failed in the language of the user. This is only provided when the transaction is marked as failed.

        :param user_failure_message: The user_failure_message of this Transaction.
        :type: str
        """

        self._user_failure_message = user_failure_message
    
    @property
    def user_interface_type(self):
        """Gets the user_interface_type of this Transaction.

            The user interface type defines through which user interface the transaction has been processed resp. created.

        :return: The user_interface_type of this Transaction.
        :rtype: TransactionUserInterfaceType
        """
        return self._user_interface_type

    @user_interface_type.setter
    def user_interface_type(self, user_interface_type):
        """Sets the user_interface_type of this Transaction.

            The user interface type defines through which user interface the transaction has been processed resp. created.

        :param user_interface_type: The user_interface_type of this Transaction.
        :type: TransactionUserInterfaceType
        """

        self._user_interface_type = user_interface_type
    
    @property
    def version(self):
        """Gets the version of this Transaction.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this Transaction.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Transaction.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this Transaction.
        :type: int
        """

        self._version = version
    
    @property
    def window_height(self):
        """Gets the window_height of this Transaction.

            

        :return: The window_height of this Transaction.
        :rtype: str
        """
        return self._window_height

    @window_height.setter
    def window_height(self, window_height):
        """Sets the window_height of this Transaction.

            

        :param window_height: The window_height of this Transaction.
        :type: str
        """

        self._window_height = window_height
    
    @property
    def window_width(self):
        """Gets the window_width of this Transaction.

            

        :return: The window_width of this Transaction.
        :rtype: str
        """
        return self._window_width

    @window_width.setter
    def window_width(self, window_width):
        """Sets the window_width of this Transaction.

            

        :param window_width: The window_width of this Transaction.
        :type: str
        """

        self._window_width = window_width
    
    @property
    def years_to_keep(self):
        """Gets the years_to_keep of this Transaction.

            The number of years the transaction will be stored after it has been authorized.

        :return: The years_to_keep of this Transaction.
        :rtype: int
        """
        return self._years_to_keep

    @years_to_keep.setter
    def years_to_keep(self, years_to_keep):
        """Sets the years_to_keep of this Transaction.

            The number of years the transaction will be stored after it has been authorized.

        :param years_to_keep: The years_to_keep of this Transaction.
        :type: int
        """

        self._years_to_keep = years_to_keep
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(Transaction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, Transaction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum
from . import TransactionAwareEntity


class TransactionVoid(TransactionAwareEntity):

    swagger_types = {
    
        'created_by': 'int',
        'created_on': 'datetime',
        'failed_on': 'datetime',
        'failure_reason': 'FailureReason',
        'labels': 'list[Label]',
        'language': 'str',
        'mode': 'TransactionVoidMode',
        'next_update_on': 'datetime',
        'planned_purge_date': 'datetime',
        'processor_reference': 'str',
        'space_view_id': 'int',
        'state': 'TransactionVoidState',
        'succeeded_on': 'datetime',
        'timeout_on': 'datetime',
        'transaction': 'Transaction',
        'version': 'int',
    }

    attribute_map = {
        'created_by': 'createdBy','created_on': 'createdOn','failed_on': 'failedOn','failure_reason': 'failureReason','labels': 'labels','language': 'language','mode': 'mode','next_update_on': 'nextUpdateOn','planned_purge_date': 'plannedPurgeDate','processor_reference': 'processorReference','space_view_id': 'spaceViewId','state': 'state','succeeded_on': 'succeededOn','timeout_on': 'timeoutOn','transaction': 'transaction','version': 'version',
    }

    
    _created_by = None
    _created_on = None
    _failed_on = None
    _failure_reason = None
    _labels = None
    _language = None
    _mode = None
    _next_update_on = None
    _planned_purge_date = None
    _processor_reference = None
    _space_view_id = None
    _state = None
    _succeeded_on = None
    _timeout_on = None
    _transaction = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.created_by = kwargs.get('created_by', None)
        self.created_on = kwargs.get('created_on', None)
        self.failed_on = kwargs.get('failed_on', None)
        self.failure_reason = kwargs.get('failure_reason', None)
        self.labels = kwargs.get('labels', None)
        self.language = kwargs.get('language', None)
        self.mode = kwargs.get('mode', None)
        self.next_update_on = kwargs.get('next_update_on', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.processor_reference = kwargs.get('processor_reference', None)
        self.space_view_id = kwargs.get('space_view_id', None)
        self.state = kwargs.get('state', None)
        self.succeeded_on = kwargs.get('succeeded_on', None)
        self.timeout_on = kwargs.get('timeout_on', None)
        self.transaction = kwargs.get('transaction', None)
        self.version = kwargs.get('version', None)
        super().__init__(**kwargs)
        self.swagger_types.update(super().swagger_types)
        self.attribute_map.update(super().attribute_map)

    
    @property
    def created_by(self):
        """Gets the created_by of this TransactionVoid.

            

        :return: The created_by of this TransactionVoid.
        :rtype: int
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this TransactionVoid.

            

        :param created_by: The created_by of this TransactionVoid.
        :type: int
        """

        self._created_by = created_by
    
    @property
    def created_on(self):
        """Gets the created_on of this TransactionVoid.

            The date and time when the object was created.

        :return: The created_on of this TransactionVoid.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this TransactionVoid.

            The date and time when the object was created.

        :param created_on: The created_on of this TransactionVoid.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def failed_on(self):
        """Gets the failed_on of this TransactionVoid.

            

        :return: The failed_on of this TransactionVoid.
        :rtype: datetime
        """
        return self._failed_on

    @failed_on.setter
    def failed_on(self, failed_on):
        """Sets the failed_on of this TransactionVoid.

            

        :param failed_on: The failed_on of this TransactionVoid.
        :type: datetime
        """

        self._failed_on = failed_on
    
    @property
    def failure_reason(self):
        """Gets the failure_reason of this TransactionVoid.

            

        :return: The failure_reason of this TransactionVoid.
        :rtype: FailureReason
        """
        return self._failure_reason

    @failure_reason.setter
    def failure_reason(self, failure_reason):
        """Sets the failure_reason of this TransactionVoid.

            

        :param failure_reason: The failure_reason of this TransactionVoid.
        :type: FailureReason
        """

        self._failure_reason = failure_reason
    
    @property
    def labels(self):
        """Gets the labels of this TransactionVoid.

            

        :return: The labels of this TransactionVoid.
        :rtype: list[Label]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this TransactionVoid.

            

        :param labels: The labels of this TransactionVoid.
        :type: list[Label]
        """

        self._labels = labels
    
    @property
    def language(self):
        """Gets the language of this TransactionVoid.

            The language that is linked to the object.

        :return: The language of this TransactionVoid.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this TransactionVoid.

            The language that is linked to the object.

        :param language: The language of this TransactionVoid.
        :type: str
        """

        self._language = language
    
    @property
    def mode(self):
        """Gets the mode of this TransactionVoid.

            

        :return: The mode of this TransactionVoid.
        :rtype: TransactionVoidMode
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        """Sets the mode of this TransactionVoid.

            

        :param mode: The mode of this TransactionVoid.
        :type: TransactionVoidMode
        """

        self._mode = mode
    
    @property
    def next_update_on(self):
        """Gets the next_update_on of this TransactionVoid.

            

        :return: The next_update_on of this TransactionVoid.
        :rtype: datetime
        """
        return self._next_update_on

    @next_update_on.setter
    def next_update_on(self, next_update_on):
        """Sets the next_update_on of this TransactionVoid.

            

        :param next_update_on: The next_update_on of this TransactionVoid.
        :type: datetime
        """

        self._next_update_on = next_update_on
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this TransactionVoid.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this TransactionVoid.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this TransactionVoid.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this TransactionVoid.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def processor_reference(self):
        """Gets the processor_reference of this TransactionVoid.

            

        :return: The processor_reference of this TransactionVoid.
        :rtype: str
        """
        return self._processor_reference

    @processor_reference.setter
    def processor_reference(self, processor_reference):
        """Sets the processor_reference of this TransactionVoid.

            

        :param processor_reference: The processor_reference of this TransactionVoid.
        :type: str
        """

        self._processor_reference = processor_reference
    
    @property
    def space_view_id(self):
        """Gets the space_view_id of this TransactionVoid.

            

        :return: The space_view_id of this TransactionVoid.
        :rtype: int
        """
        return self._space_view_id

    @space_view_id.setter
    def space_view_id(self, space_view_id):
        """Sets the space_view_id of this TransactionVoid.

            

        :param space_view_id: The space_view_id of this TransactionVoid.
        :type: int
        """

        self._space_view_id = space_view_id
    
    @property
    def state(self):
        """Gets the state of this TransactionVoid.

            The object's current state.

        :return: The state of this TransactionVoid.
        :rtype: TransactionVoidState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this TransactionVoid.

            The object's current state.

        :param state: The state of this TransactionVoid.
        :type: TransactionVoidState
        """

        self._state = state
    
    @property
    def succeeded_on(self):
        """Gets the succeeded_on of this TransactionVoid.

            

        :return: The succeeded_on of this TransactionVoid.
        :rtype: datetime
        """
        return self._succeeded_on

    @succeeded_on.setter
    def succeeded_on(self, succeeded_on):
        """Sets the succeeded_on of this TransactionVoid.

            

        :param succeeded_on: The succeeded_on of this TransactionVoid.
        :type: datetime
        """

        self._succeeded_on = succeeded_on
    
    @property
    def timeout_on(self):
        """Gets the timeout_on of this TransactionVoid.

            

        :return: The timeout_on of this TransactionVoid.
        :rtype: datetime
        """
        return self._timeout_on

    @timeout_on.setter
    def timeout_on(self, timeout_on):
        """Sets the timeout_on of this TransactionVoid.

            

        :param timeout_on: The timeout_on of this TransactionVoid.
        :type: datetime
        """

        self._timeout_on = timeout_on
    
    @property
    def transaction(self):
        """Gets the transaction of this TransactionVoid.

            

        :return: The transaction of this TransactionVoid.
        :rtype: Transaction
        """
        return self._transaction

    @transaction.setter
    def transaction(self, transaction):
        """Sets the transaction of this TransactionVoid.

            

        :param transaction: The transaction of this TransactionVoid.
        :type: Transaction
        """

        self._transaction = transaction
    
    @property
    def version(self):
        """Gets the version of this TransactionVoid.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this TransactionVoid.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this TransactionVoid.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this TransactionVoid.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(TransactionVoid, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, TransactionVoid):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class PaymentAppRefundUpdateRequest:

    swagger_types = {
    
        'failure_reason_id': 'int',
        'reference': 'str',
        'refund_id': 'int',
        'target_state': 'PaymentAppRefundTargetState',
    }

    attribute_map = {
        'failure_reason_id': 'failureReasonId','reference': 'reference','refund_id': 'refundId','target_state': 'targetState',
    }

    
    _failure_reason_id = None
    _reference = None
    _refund_id = None
    _target_state = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.failure_reason_id = kwargs.get('failure_reason_id', None)
        self.reference = kwargs.get('reference', None)
        self.refund_id = kwargs.get('refund_id', None)
        self.target_state = kwargs.get('target_state', None)
        

    
    @property
    def failure_reason_id(self):
        """Gets the failure_reason_id of this PaymentAppRefundUpdateRequest.

            The failure reason indicates why the refund failed. It is required when the target state is FAILED.

        :return: The failure_reason_id of this PaymentAppRefundUpdateRequest.
        :rtype: int
        """
        return self._failure_reason_id

    @failure_reason_id.setter
    def failure_reason_id(self, failure_reason_id):
        """Sets the failure_reason_id of this PaymentAppRefundUpdateRequest.

            The failure reason indicates why the refund failed. It is required when the target state is FAILED.

        :param failure_reason_id: The failure_reason_id of this PaymentAppRefundUpdateRequest.
        :type: int
        """

        self._failure_reason_id = failure_reason_id
    
    @property
    def reference(self):
        """Gets the reference of this PaymentAppRefundUpdateRequest.

            The reference identifies the refund within the systems of the external service provider. It is required when the target state is SUCCESSFUL.

        :return: The reference of this PaymentAppRefundUpdateRequest.
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this PaymentAppRefundUpdateRequest.

            The reference identifies the refund within the systems of the external service provider. It is required when the target state is SUCCESSFUL.

        :param reference: The reference of this PaymentAppRefundUpdateRequest.
        :type: str
        """
        if reference is not None and len(reference) > 100:
            raise ValueError("Invalid value for `reference`, length must be less than or equal to `100`")

        self._reference = reference
    
    @property
    def refund_id(self):
        """Gets the refund_id of this PaymentAppRefundUpdateRequest.

            This is the ID of the refund that should be updated.

        :return: The refund_id of this PaymentAppRefundUpdateRequest.
        :rtype: int
        """
        return self._refund_id

    @refund_id.setter
    def refund_id(self, refund_id):
        """Sets the refund_id of this PaymentAppRefundUpdateRequest.

            This is the ID of the refund that should be updated.

        :param refund_id: The refund_id of this PaymentAppRefundUpdateRequest.
        :type: int
        """

        self._refund_id = refund_id
    
    @property
    def target_state(self):
        """Gets the target_state of this PaymentAppRefundUpdateRequest.

            The target state defines the state into which the refund should be switched into. Once the refund changed the state it will not be possible to change it again.

        :return: The target_state of this PaymentAppRefundUpdateRequest.
        :rtype: PaymentAppRefundTargetState
        """
        return self._target_state

    @target_state.setter
    def target_state(self, target_state):
        """Sets the target_state of this PaymentAppRefundUpdateRequest.

            The target state defines the state into which the refund should be switched into. Once the refund changed the state it will not be possible to change it again.

        :param target_state: The target_state of this PaymentAppRefundUpdateRequest.
        :type: PaymentAppRefundTargetState
        """

        self._target_state = target_state
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(PaymentAppRefundUpdateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, PaymentAppRefundUpdateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class Feature:

    swagger_types = {
    
        'beta': 'bool',
        'category': 'FeatureCategory',
        'description': 'dict(str, str)',
        'id': 'int',
        'logo_path': 'str',
        'name': 'dict(str, str)',
        'required_features': 'list[int]',
        'sort_order': 'int',
        'visible': 'bool',
    }

    attribute_map = {
        'beta': 'beta','category': 'category','description': 'description','id': 'id','logo_path': 'logoPath','name': 'name','required_features': 'requiredFeatures','sort_order': 'sortOrder','visible': 'visible',
    }

    
    _beta = None
    _category = None
    _description = None
    _id = None
    _logo_path = None
    _name = None
    _required_features = None
    _sort_order = None
    _visible = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.beta = kwargs.get('beta', None)
        self.category = kwargs.get('category', None)
        self.description = kwargs.get('description', None)
        self.id = kwargs.get('id', None)
        self.logo_path = kwargs.get('logo_path', None)
        self.name = kwargs.get('name', None)
        self.required_features = kwargs.get('required_features', None)
        self.sort_order = kwargs.get('sort_order', None)
        self.visible = kwargs.get('visible', None)
        

    
    @property
    def beta(self):
        """Gets the beta of this Feature.

            Whether the feature is in beta stage and there may still be some issues.

        :return: The beta of this Feature.
        :rtype: bool
        """
        return self._beta

    @beta.setter
    def beta(self, beta):
        """Sets the beta of this Feature.

            Whether the feature is in beta stage and there may still be some issues.

        :param beta: The beta of this Feature.
        :type: bool
        """

        self._beta = beta
    
    @property
    def category(self):
        """Gets the category of this Feature.

            The category that the feature belongs to.

        :return: The category of this Feature.
        :rtype: FeatureCategory
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this Feature.

            The category that the feature belongs to.

        :param category: The category of this Feature.
        :type: FeatureCategory
        """

        self._category = category
    
    @property
    def description(self):
        """Gets the description of this Feature.

            The localized description of the object.

        :return: The description of this Feature.
        :rtype: dict(str, str)
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Feature.

            The localized description of the object.

        :param description: The description of this Feature.
        :type: dict(str, str)
        """

        self._description = description
    
    @property
    def id(self):
        """Gets the id of this Feature.

            A unique identifier for the object.

        :return: The id of this Feature.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Feature.

            A unique identifier for the object.

        :param id: The id of this Feature.
        :type: int
        """

        self._id = id
    
    @property
    def logo_path(self):
        """Gets the logo_path of this Feature.

            The path to the feature's logo image.

        :return: The logo_path of this Feature.
        :rtype: str
        """
        return self._logo_path

    @logo_path.setter
    def logo_path(self, logo_path):
        """Sets the logo_path of this Feature.

            The path to the feature's logo image.

        :param logo_path: The logo_path of this Feature.
        :type: str
        """

        self._logo_path = logo_path
    
    @property
    def name(self):
        """Gets the name of this Feature.

            The localized name of the object.

        :return: The name of this Feature.
        :rtype: dict(str, str)
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Feature.

            The localized name of the object.

        :param name: The name of this Feature.
        :type: dict(str, str)
        """

        self._name = name
    
    @property
    def required_features(self):
        """Gets the required_features of this Feature.

            The features that must be enabled for this feature to work properly.

        :return: The required_features of this Feature.
        :rtype: list[int]
        """
        return self._required_features

    @required_features.setter
    def required_features(self, required_features):
        """Sets the required_features of this Feature.

            The features that must be enabled for this feature to work properly.

        :param required_features: The required_features of this Feature.
        :type: list[int]
        """

        self._required_features = required_features
    
    @property
    def sort_order(self):
        """Gets the sort_order of this Feature.

            When listing features, they can be sorted by this number.

        :return: The sort_order of this Feature.
        :rtype: int
        """
        return self._sort_order

    @sort_order.setter
    def sort_order(self, sort_order):
        """Sets the sort_order of this Feature.

            When listing features, they can be sorted by this number.

        :param sort_order: The sort_order of this Feature.
        :type: int
        """

        self._sort_order = sort_order
    
    @property
    def visible(self):
        """Gets the visible of this Feature.

            

        :return: The visible of this Feature.
        :rtype: bool
        """
        return self._visible

    @visible.setter
    def visible(self, visible):
        """Sets the visible of this Feature.

            

        :param visible: The visible of this Feature.
        :type: bool
        """

        self._visible = visible
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(Feature, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, Feature):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class SubscriptionCreateRequest:

    swagger_types = {
    
        'component_configurations': 'list[SubscriptionComponentReferenceConfiguration]',
        'currency': 'str',
        'product': 'int',
        'selected_components': 'list[SubscriptionProductComponentReference]',
        'subscription': 'SubscriptionPending',
    }

    attribute_map = {
        'component_configurations': 'componentConfigurations','currency': 'currency','product': 'product','selected_components': 'selectedComponents','subscription': 'subscription',
    }

    
    _component_configurations = None
    _currency = None
    _product = None
    _selected_components = None
    _subscription = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.component_configurations = kwargs.get('component_configurations', None)
        self.currency = kwargs.get('currency')

        self.product = kwargs.get('product')

        self.selected_components = kwargs.get('selected_components', None)
        self.subscription = kwargs.get('subscription')

        

    
    @property
    def component_configurations(self):
        """Gets the component_configurations of this SubscriptionCreateRequest.

            

        :return: The component_configurations of this SubscriptionCreateRequest.
        :rtype: list[SubscriptionComponentReferenceConfiguration]
        """
        return self._component_configurations

    @component_configurations.setter
    def component_configurations(self, component_configurations):
        """Sets the component_configurations of this SubscriptionCreateRequest.

            

        :param component_configurations: The component_configurations of this SubscriptionCreateRequest.
        :type: list[SubscriptionComponentReferenceConfiguration]
        """

        self._component_configurations = component_configurations
    
    @property
    def currency(self):
        """Gets the currency of this SubscriptionCreateRequest.

            

        :return: The currency of this SubscriptionCreateRequest.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this SubscriptionCreateRequest.

            

        :param currency: The currency of this SubscriptionCreateRequest.
        :type: str
        """
        if currency is None:
            raise ValueError("Invalid value for `currency`, must not be `None`")

        self._currency = currency
    
    @property
    def product(self):
        """Gets the product of this SubscriptionCreateRequest.

            The subscription has to be linked with a product.

        :return: The product of this SubscriptionCreateRequest.
        :rtype: int
        """
        return self._product

    @product.setter
    def product(self, product):
        """Sets the product of this SubscriptionCreateRequest.

            The subscription has to be linked with a product.

        :param product: The product of this SubscriptionCreateRequest.
        :type: int
        """
        if product is None:
            raise ValueError("Invalid value for `product`, must not be `None`")

        self._product = product
    
    @property
    def selected_components(self):
        """Gets the selected_components of this SubscriptionCreateRequest.

            

        :return: The selected_components of this SubscriptionCreateRequest.
        :rtype: list[SubscriptionProductComponentReference]
        """
        return self._selected_components

    @selected_components.setter
    def selected_components(self, selected_components):
        """Sets the selected_components of this SubscriptionCreateRequest.

            

        :param selected_components: The selected_components of this SubscriptionCreateRequest.
        :type: list[SubscriptionProductComponentReference]
        """

        self._selected_components = selected_components
    
    @property
    def subscription(self):
        """Gets the subscription of this SubscriptionCreateRequest.

            

        :return: The subscription of this SubscriptionCreateRequest.
        :rtype: SubscriptionPending
        """
        return self._subscription

    @subscription.setter
    def subscription(self, subscription):
        """Sets the subscription of this SubscriptionCreateRequest.

            

        :param subscription: The subscription of this SubscriptionCreateRequest.
        :type: SubscriptionPending
        """
        if subscription is None:
            raise ValueError("Invalid value for `subscription`, must not be `None`")

        self._subscription = subscription
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(SubscriptionCreateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, SubscriptionCreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class WebAppConfirmationResponse:

    swagger_types = {
    
        'access_token': 'str',
        'scope': 'str',
        'space': 'Space',
        'state': 'str',
        'token_type': 'str',
    }

    attribute_map = {
        'access_token': 'access_token','scope': 'scope','space': 'space','state': 'state','token_type': 'token_type',
    }

    
    _access_token = None
    _scope = None
    _space = None
    _state = None
    _token_type = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.access_token = kwargs.get('access_token', None)
        self.scope = kwargs.get('scope', None)
        self.space = kwargs.get('space', None)
        self.state = kwargs.get('state', None)
        self.token_type = kwargs.get('token_type', None)
        

    
    @property
    def access_token(self):
        """Gets the access_token of this WebAppConfirmationResponse.

            The access code grants permissions to the web service API according to the OAuth standard.

        :return: The access_token of this WebAppConfirmationResponse.
        :rtype: str
        """
        return self._access_token

    @access_token.setter
    def access_token(self, access_token):
        """Sets the access_token of this WebAppConfirmationResponse.

            The access code grants permissions to the web service API according to the OAuth standard.

        :param access_token: The access_token of this WebAppConfirmationResponse.
        :type: str
        """

        self._access_token = access_token
    
    @property
    def scope(self):
        """Gets the scope of this WebAppConfirmationResponse.

            The scope contains the permissions granted to the web app within the space.

        :return: The scope of this WebAppConfirmationResponse.
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this WebAppConfirmationResponse.

            The scope contains the permissions granted to the web app within the space.

        :param scope: The scope of this WebAppConfirmationResponse.
        :type: str
        """

        self._scope = scope
    
    @property
    def space(self):
        """Gets the space of this WebAppConfirmationResponse.

            This is the space into which the web app is installed into.

        :return: The space of this WebAppConfirmationResponse.
        :rtype: Space
        """
        return self._space

    @space.setter
    def space(self, space):
        """Sets the space of this WebAppConfirmationResponse.

            This is the space into which the web app is installed into.

        :param space: The space of this WebAppConfirmationResponse.
        :type: Space
        """

        self._space = space
    
    @property
    def state(self):
        """Gets the state of this WebAppConfirmationResponse.

            The state contains the state parameter content provided when initiating the app installation.

        :return: The state of this WebAppConfirmationResponse.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this WebAppConfirmationResponse.

            The state contains the state parameter content provided when initiating the app installation.

        :param state: The state of this WebAppConfirmationResponse.
        :type: str
        """

        self._state = state
    
    @property
    def token_type(self):
        """Gets the token_type of this WebAppConfirmationResponse.

            The token type indicates the type of the access token. The type determines the authentication mechanism to use for accessing the web service API.

        :return: The token_type of this WebAppConfirmationResponse.
        :rtype: str
        """
        return self._token_type

    @token_type.setter
    def token_type(self, token_type):
        """Sets the token_type of this WebAppConfirmationResponse.

            The token type indicates the type of the access token. The type determines the authentication mechanism to use for accessing the web service API.

        :param token_type: The token_type of this WebAppConfirmationResponse.
        :type: str
        """

        self._token_type = token_type
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(WebAppConfirmationResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, WebAppConfirmationResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class DebtCollectionCase:

    swagger_types = {
    
        'amount': 'float',
        'billing_address': 'Address',
        'closed_on': 'datetime',
        'collector_configuration': 'DebtCollectorConfiguration',
        'contract_date': 'datetime',
        'created_on': 'datetime',
        'creator': 'int',
        'currency': 'str',
        'due_date': 'datetime',
        'environment': 'DebtCollectionEnvironment',
        'external_id': 'str',
        'failed_on': 'datetime',
        'failure_reason': 'FailureReason',
        'id': 'int',
        'labels': 'list[Label]',
        'language': 'str',
        'line_items': 'list[LineItem]',
        'linked_space_id': 'int',
        'next_attempt_on': 'datetime',
        'planned_purge_date': 'datetime',
        'processing_started_on': 'datetime',
        'processing_timeout_on': 'datetime',
        'reference': 'str',
        'review_started_on': 'datetime',
        'reviewed_on': 'datetime',
        'reviewer': 'int',
        'source': 'DebtCollectionCaseSource',
        'source_entity_id': 'int',
        'space_view_id': 'int',
        'state': 'DebtCollectionCaseState',
        'version': 'int',
    }

    attribute_map = {
        'amount': 'amount','billing_address': 'billingAddress','closed_on': 'closedOn','collector_configuration': 'collectorConfiguration','contract_date': 'contractDate','created_on': 'createdOn','creator': 'creator','currency': 'currency','due_date': 'dueDate','environment': 'environment','external_id': 'externalId','failed_on': 'failedOn','failure_reason': 'failureReason','id': 'id','labels': 'labels','language': 'language','line_items': 'lineItems','linked_space_id': 'linkedSpaceId','next_attempt_on': 'nextAttemptOn','planned_purge_date': 'plannedPurgeDate','processing_started_on': 'processingStartedOn','processing_timeout_on': 'processingTimeoutOn','reference': 'reference','review_started_on': 'reviewStartedOn','reviewed_on': 'reviewedOn','reviewer': 'reviewer','source': 'source','source_entity_id': 'sourceEntityId','space_view_id': 'spaceViewId','state': 'state','version': 'version',
    }

    
    _amount = None
    _billing_address = None
    _closed_on = None
    _collector_configuration = None
    _contract_date = None
    _created_on = None
    _creator = None
    _currency = None
    _due_date = None
    _environment = None
    _external_id = None
    _failed_on = None
    _failure_reason = None
    _id = None
    _labels = None
    _language = None
    _line_items = None
    _linked_space_id = None
    _next_attempt_on = None
    _planned_purge_date = None
    _processing_started_on = None
    _processing_timeout_on = None
    _reference = None
    _review_started_on = None
    _reviewed_on = None
    _reviewer = None
    _source = None
    _source_entity_id = None
    _space_view_id = None
    _state = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.amount = kwargs.get('amount', None)
        self.billing_address = kwargs.get('billing_address', None)
        self.closed_on = kwargs.get('closed_on', None)
        self.collector_configuration = kwargs.get('collector_configuration', None)
        self.contract_date = kwargs.get('contract_date', None)
        self.created_on = kwargs.get('created_on', None)
        self.creator = kwargs.get('creator', None)
        self.currency = kwargs.get('currency', None)
        self.due_date = kwargs.get('due_date', None)
        self.environment = kwargs.get('environment', None)
        self.external_id = kwargs.get('external_id', None)
        self.failed_on = kwargs.get('failed_on', None)
        self.failure_reason = kwargs.get('failure_reason', None)
        self.id = kwargs.get('id', None)
        self.labels = kwargs.get('labels', None)
        self.language = kwargs.get('language', None)
        self.line_items = kwargs.get('line_items', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.next_attempt_on = kwargs.get('next_attempt_on', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.processing_started_on = kwargs.get('processing_started_on', None)
        self.processing_timeout_on = kwargs.get('processing_timeout_on', None)
        self.reference = kwargs.get('reference', None)
        self.review_started_on = kwargs.get('review_started_on', None)
        self.reviewed_on = kwargs.get('reviewed_on', None)
        self.reviewer = kwargs.get('reviewer', None)
        self.source = kwargs.get('source', None)
        self.source_entity_id = kwargs.get('source_entity_id', None)
        self.space_view_id = kwargs.get('space_view_id', None)
        self.state = kwargs.get('state', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def amount(self):
        """Gets the amount of this DebtCollectionCase.

            The amount is the total amount of the not paid items. The amount cannot be change once the case is reviewed.

        :return: The amount of this DebtCollectionCase.
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this DebtCollectionCase.

            The amount is the total amount of the not paid items. The amount cannot be change once the case is reviewed.

        :param amount: The amount of this DebtCollectionCase.
        :type: float
        """

        self._amount = amount
    
    @property
    def billing_address(self):
        """Gets the billing_address of this DebtCollectionCase.

            The billing address of the case identifies the debtor.

        :return: The billing_address of this DebtCollectionCase.
        :rtype: Address
        """
        return self._billing_address

    @billing_address.setter
    def billing_address(self, billing_address):
        """Sets the billing_address of this DebtCollectionCase.

            The billing address of the case identifies the debtor.

        :param billing_address: The billing_address of this DebtCollectionCase.
        :type: Address
        """

        self._billing_address = billing_address
    
    @property
    def closed_on(self):
        """Gets the closed_on of this DebtCollectionCase.

            The closed on date indicates when the case is closed on.

        :return: The closed_on of this DebtCollectionCase.
        :rtype: datetime
        """
        return self._closed_on

    @closed_on.setter
    def closed_on(self, closed_on):
        """Sets the closed_on of this DebtCollectionCase.

            The closed on date indicates when the case is closed on.

        :param closed_on: The closed_on of this DebtCollectionCase.
        :type: datetime
        """

        self._closed_on = closed_on
    
    @property
    def collector_configuration(self):
        """Gets the collector_configuration of this DebtCollectionCase.

            The collector configuration determines how the debt collection case is processed.

        :return: The collector_configuration of this DebtCollectionCase.
        :rtype: DebtCollectorConfiguration
        """
        return self._collector_configuration

    @collector_configuration.setter
    def collector_configuration(self, collector_configuration):
        """Sets the collector_configuration of this DebtCollectionCase.

            The collector configuration determines how the debt collection case is processed.

        :param collector_configuration: The collector_configuration of this DebtCollectionCase.
        :type: DebtCollectorConfiguration
        """

        self._collector_configuration = collector_configuration
    
    @property
    def contract_date(self):
        """Gets the contract_date of this DebtCollectionCase.

            The contract date is the date on which the contract with the debtor was signed on.

        :return: The contract_date of this DebtCollectionCase.
        :rtype: datetime
        """
        return self._contract_date

    @contract_date.setter
    def contract_date(self, contract_date):
        """Sets the contract_date of this DebtCollectionCase.

            The contract date is the date on which the contract with the debtor was signed on.

        :param contract_date: The contract_date of this DebtCollectionCase.
        :type: datetime
        """

        self._contract_date = contract_date
    
    @property
    def created_on(self):
        """Gets the created_on of this DebtCollectionCase.

            The date and time when the object was created.

        :return: The created_on of this DebtCollectionCase.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this DebtCollectionCase.

            The date and time when the object was created.

        :param created_on: The created_on of this DebtCollectionCase.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def creator(self):
        """Gets the creator of this DebtCollectionCase.

            The creator references the user which has created the debt collection case.

        :return: The creator of this DebtCollectionCase.
        :rtype: int
        """
        return self._creator

    @creator.setter
    def creator(self, creator):
        """Sets the creator of this DebtCollectionCase.

            The creator references the user which has created the debt collection case.

        :param creator: The creator of this DebtCollectionCase.
        :type: int
        """

        self._creator = creator
    
    @property
    def currency(self):
        """Gets the currency of this DebtCollectionCase.

            The currency defines the billing currency of the debt collection case.

        :return: The currency of this DebtCollectionCase.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this DebtCollectionCase.

            The currency defines the billing currency of the debt collection case.

        :param currency: The currency of this DebtCollectionCase.
        :type: str
        """

        self._currency = currency
    
    @property
    def due_date(self):
        """Gets the due_date of this DebtCollectionCase.

            The due date indicates the date on which the amount receivable was due. This date has to be always in the past.

        :return: The due_date of this DebtCollectionCase.
        :rtype: datetime
        """
        return self._due_date

    @due_date.setter
    def due_date(self, due_date):
        """Sets the due_date of this DebtCollectionCase.

            The due date indicates the date on which the amount receivable was due. This date has to be always in the past.

        :param due_date: The due_date of this DebtCollectionCase.
        :type: datetime
        """

        self._due_date = due_date
    
    @property
    def environment(self):
        """Gets the environment of this DebtCollectionCase.

            The environment in which this case will be processed. There must be a debt collector configuration present which supports the chosen environment.

        :return: The environment of this DebtCollectionCase.
        :rtype: DebtCollectionEnvironment
        """
        return self._environment

    @environment.setter
    def environment(self, environment):
        """Sets the environment of this DebtCollectionCase.

            The environment in which this case will be processed. There must be a debt collector configuration present which supports the chosen environment.

        :param environment: The environment of this DebtCollectionCase.
        :type: DebtCollectionEnvironment
        """

        self._environment = environment
    
    @property
    def external_id(self):
        """Gets the external_id of this DebtCollectionCase.

            A client generated nonce which identifies the entity to be created. Subsequent creation requests with the same external ID will not create new entities but return the initially created entity instead.

        :return: The external_id of this DebtCollectionCase.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this DebtCollectionCase.

            A client generated nonce which identifies the entity to be created. Subsequent creation requests with the same external ID will not create new entities but return the initially created entity instead.

        :param external_id: The external_id of this DebtCollectionCase.
        :type: str
        """

        self._external_id = external_id
    
    @property
    def failed_on(self):
        """Gets the failed_on of this DebtCollectionCase.

            The failed on date indicates when the case is failed on.

        :return: The failed_on of this DebtCollectionCase.
        :rtype: datetime
        """
        return self._failed_on

    @failed_on.setter
    def failed_on(self, failed_on):
        """Sets the failed_on of this DebtCollectionCase.

            The failed on date indicates when the case is failed on.

        :param failed_on: The failed_on of this DebtCollectionCase.
        :type: datetime
        """

        self._failed_on = failed_on
    
    @property
    def failure_reason(self):
        """Gets the failure_reason of this DebtCollectionCase.

            

        :return: The failure_reason of this DebtCollectionCase.
        :rtype: FailureReason
        """
        return self._failure_reason

    @failure_reason.setter
    def failure_reason(self, failure_reason):
        """Sets the failure_reason of this DebtCollectionCase.

            

        :param failure_reason: The failure_reason of this DebtCollectionCase.
        :type: FailureReason
        """

        self._failure_reason = failure_reason
    
    @property
    def id(self):
        """Gets the id of this DebtCollectionCase.

            A unique identifier for the object.

        :return: The id of this DebtCollectionCase.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DebtCollectionCase.

            A unique identifier for the object.

        :param id: The id of this DebtCollectionCase.
        :type: int
        """

        self._id = id
    
    @property
    def labels(self):
        """Gets the labels of this DebtCollectionCase.

            

        :return: The labels of this DebtCollectionCase.
        :rtype: list[Label]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this DebtCollectionCase.

            

        :param labels: The labels of this DebtCollectionCase.
        :type: list[Label]
        """

        self._labels = labels
    
    @property
    def language(self):
        """Gets the language of this DebtCollectionCase.

            The language indicates the language to be used in the communication with the debtor.

        :return: The language of this DebtCollectionCase.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this DebtCollectionCase.

            The language indicates the language to be used in the communication with the debtor.

        :param language: The language of this DebtCollectionCase.
        :type: str
        """

        self._language = language
    
    @property
    def line_items(self):
        """Gets the line_items of this DebtCollectionCase.

            The line items of the debt collection case will be shown on documents sent to the debtor and the total of them makes up total amount to collect.

        :return: The line_items of this DebtCollectionCase.
        :rtype: list[LineItem]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """Sets the line_items of this DebtCollectionCase.

            The line items of the debt collection case will be shown on documents sent to the debtor and the total of them makes up total amount to collect.

        :param line_items: The line_items of this DebtCollectionCase.
        :type: list[LineItem]
        """

        self._line_items = line_items
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this DebtCollectionCase.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this DebtCollectionCase.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this DebtCollectionCase.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this DebtCollectionCase.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def next_attempt_on(self):
        """Gets the next_attempt_on of this DebtCollectionCase.

            

        :return: The next_attempt_on of this DebtCollectionCase.
        :rtype: datetime
        """
        return self._next_attempt_on

    @next_attempt_on.setter
    def next_attempt_on(self, next_attempt_on):
        """Sets the next_attempt_on of this DebtCollectionCase.

            

        :param next_attempt_on: The next_attempt_on of this DebtCollectionCase.
        :type: datetime
        """

        self._next_attempt_on = next_attempt_on
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this DebtCollectionCase.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this DebtCollectionCase.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this DebtCollectionCase.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this DebtCollectionCase.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def processing_started_on(self):
        """Gets the processing_started_on of this DebtCollectionCase.

            The processing started on date indicates the date on which the processing of the case started on.

        :return: The processing_started_on of this DebtCollectionCase.
        :rtype: datetime
        """
        return self._processing_started_on

    @processing_started_on.setter
    def processing_started_on(self, processing_started_on):
        """Sets the processing_started_on of this DebtCollectionCase.

            The processing started on date indicates the date on which the processing of the case started on.

        :param processing_started_on: The processing_started_on of this DebtCollectionCase.
        :type: datetime
        """

        self._processing_started_on = processing_started_on
    
    @property
    def processing_timeout_on(self):
        """Gets the processing_timeout_on of this DebtCollectionCase.

            

        :return: The processing_timeout_on of this DebtCollectionCase.
        :rtype: datetime
        """
        return self._processing_timeout_on

    @processing_timeout_on.setter
    def processing_timeout_on(self, processing_timeout_on):
        """Sets the processing_timeout_on of this DebtCollectionCase.

            

        :param processing_timeout_on: The processing_timeout_on of this DebtCollectionCase.
        :type: datetime
        """

        self._processing_timeout_on = processing_timeout_on
    
    @property
    def reference(self):
        """Gets the reference of this DebtCollectionCase.

            The case reference is used in the communication with the debtor. It should be unique and it should be linkable with the source of the debt collection case.

        :return: The reference of this DebtCollectionCase.
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this DebtCollectionCase.

            The case reference is used in the communication with the debtor. It should be unique and it should be linkable with the source of the debt collection case.

        :param reference: The reference of this DebtCollectionCase.
        :type: str
        """

        self._reference = reference
    
    @property
    def review_started_on(self):
        """Gets the review_started_on of this DebtCollectionCase.

            

        :return: The review_started_on of this DebtCollectionCase.
        :rtype: datetime
        """
        return self._review_started_on

    @review_started_on.setter
    def review_started_on(self, review_started_on):
        """Sets the review_started_on of this DebtCollectionCase.

            

        :param review_started_on: The review_started_on of this DebtCollectionCase.
        :type: datetime
        """

        self._review_started_on = review_started_on
    
    @property
    def reviewed_on(self):
        """Gets the reviewed_on of this DebtCollectionCase.

            The reviewed on date indicates when the review of the case was conducted on.

        :return: The reviewed_on of this DebtCollectionCase.
        :rtype: datetime
        """
        return self._reviewed_on

    @reviewed_on.setter
    def reviewed_on(self, reviewed_on):
        """Sets the reviewed_on of this DebtCollectionCase.

            The reviewed on date indicates when the review of the case was conducted on.

        :param reviewed_on: The reviewed_on of this DebtCollectionCase.
        :type: datetime
        """

        self._reviewed_on = reviewed_on
    
    @property
    def reviewer(self):
        """Gets the reviewer of this DebtCollectionCase.

            The reviewer references the user which has reviewed the case.

        :return: The reviewer of this DebtCollectionCase.
        :rtype: int
        """
        return self._reviewer

    @reviewer.setter
    def reviewer(self, reviewer):
        """Sets the reviewer of this DebtCollectionCase.

            The reviewer references the user which has reviewed the case.

        :param reviewer: The reviewer of this DebtCollectionCase.
        :type: int
        """

        self._reviewer = reviewer
    
    @property
    def source(self):
        """Gets the source of this DebtCollectionCase.

            The source of the debt collection case indicates the origin of the amount receivable.

        :return: The source of this DebtCollectionCase.
        :rtype: DebtCollectionCaseSource
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this DebtCollectionCase.

            The source of the debt collection case indicates the origin of the amount receivable.

        :param source: The source of this DebtCollectionCase.
        :type: DebtCollectionCaseSource
        """

        self._source = source
    
    @property
    def source_entity_id(self):
        """Gets the source_entity_id of this DebtCollectionCase.

            The source entity ID points to the object which is the origin of the debt collection case. This ID is only set when the case was triggered by an internal process.

        :return: The source_entity_id of this DebtCollectionCase.
        :rtype: int
        """
        return self._source_entity_id

    @source_entity_id.setter
    def source_entity_id(self, source_entity_id):
        """Sets the source_entity_id of this DebtCollectionCase.

            The source entity ID points to the object which is the origin of the debt collection case. This ID is only set when the case was triggered by an internal process.

        :param source_entity_id: The source_entity_id of this DebtCollectionCase.
        :type: int
        """

        self._source_entity_id = source_entity_id
    
    @property
    def space_view_id(self):
        """Gets the space_view_id of this DebtCollectionCase.

            

        :return: The space_view_id of this DebtCollectionCase.
        :rtype: int
        """
        return self._space_view_id

    @space_view_id.setter
    def space_view_id(self, space_view_id):
        """Sets the space_view_id of this DebtCollectionCase.

            

        :param space_view_id: The space_view_id of this DebtCollectionCase.
        :type: int
        """

        self._space_view_id = space_view_id
    
    @property
    def state(self):
        """Gets the state of this DebtCollectionCase.

            The object's current state.

        :return: The state of this DebtCollectionCase.
        :rtype: DebtCollectionCaseState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this DebtCollectionCase.

            The object's current state.

        :param state: The state of this DebtCollectionCase.
        :type: DebtCollectionCaseState
        """

        self._state = state
    
    @property
    def version(self):
        """Gets the version of this DebtCollectionCase.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this DebtCollectionCase.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this DebtCollectionCase.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this DebtCollectionCase.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(DebtCollectionCase, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, DebtCollectionCase):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class AbstractCustomerCommentActive:

    swagger_types = {
    
        'content': 'str',
    }

    attribute_map = {
        'content': 'content',
    }

    
    _content = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.content = kwargs.get('content', None)
        

    
    @property
    def content(self):
        """Gets the content of this AbstractCustomerCommentActive.

            The comment's actual content.

        :return: The content of this AbstractCustomerCommentActive.
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this AbstractCustomerCommentActive.

            The comment's actual content.

        :param content: The content of this AbstractCustomerCommentActive.
        :type: str
        """
        if content is not None and len(content) > 262144:
            raise ValueError("Invalid value for `content`, length must be less than or equal to `262144`")

        self._content = content
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(AbstractCustomerCommentActive, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, AbstractCustomerCommentActive):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum
from . import TransactionAwareEntity


class DeliveryIndication(TransactionAwareEntity):

    swagger_types = {
    
        'automatic_decision_reason': 'DeliveryIndicationDecisionReason',
        'automatically_decided_on': 'datetime',
        'completion': 'int',
        'created_on': 'datetime',
        'manual_decision_timeout_on': 'datetime',
        'manually_decided_by': 'int',
        'manually_decided_on': 'datetime',
        'planned_purge_date': 'datetime',
        'state': 'DeliveryIndicationState',
        'timeout_on': 'datetime',
        'transaction': 'Transaction',
    }

    attribute_map = {
        'automatic_decision_reason': 'automaticDecisionReason','automatically_decided_on': 'automaticallyDecidedOn','completion': 'completion','created_on': 'createdOn','manual_decision_timeout_on': 'manualDecisionTimeoutOn','manually_decided_by': 'manuallyDecidedBy','manually_decided_on': 'manuallyDecidedOn','planned_purge_date': 'plannedPurgeDate','state': 'state','timeout_on': 'timeoutOn','transaction': 'transaction',
    }

    
    _automatic_decision_reason = None
    _automatically_decided_on = None
    _completion = None
    _created_on = None
    _manual_decision_timeout_on = None
    _manually_decided_by = None
    _manually_decided_on = None
    _planned_purge_date = None
    _state = None
    _timeout_on = None
    _transaction = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.automatic_decision_reason = kwargs.get('automatic_decision_reason', None)
        self.automatically_decided_on = kwargs.get('automatically_decided_on', None)
        self.completion = kwargs.get('completion', None)
        self.created_on = kwargs.get('created_on', None)
        self.manual_decision_timeout_on = kwargs.get('manual_decision_timeout_on', None)
        self.manually_decided_by = kwargs.get('manually_decided_by', None)
        self.manually_decided_on = kwargs.get('manually_decided_on', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.state = kwargs.get('state', None)
        self.timeout_on = kwargs.get('timeout_on', None)
        self.transaction = kwargs.get('transaction', None)
        super().__init__(**kwargs)
        self.swagger_types.update(super().swagger_types)
        self.attribute_map.update(super().attribute_map)

    
    @property
    def automatic_decision_reason(self):
        """Gets the automatic_decision_reason of this DeliveryIndication.

            

        :return: The automatic_decision_reason of this DeliveryIndication.
        :rtype: DeliveryIndicationDecisionReason
        """
        return self._automatic_decision_reason

    @automatic_decision_reason.setter
    def automatic_decision_reason(self, automatic_decision_reason):
        """Sets the automatic_decision_reason of this DeliveryIndication.

            

        :param automatic_decision_reason: The automatic_decision_reason of this DeliveryIndication.
        :type: DeliveryIndicationDecisionReason
        """

        self._automatic_decision_reason = automatic_decision_reason
    
    @property
    def automatically_decided_on(self):
        """Gets the automatically_decided_on of this DeliveryIndication.

            

        :return: The automatically_decided_on of this DeliveryIndication.
        :rtype: datetime
        """
        return self._automatically_decided_on

    @automatically_decided_on.setter
    def automatically_decided_on(self, automatically_decided_on):
        """Sets the automatically_decided_on of this DeliveryIndication.

            

        :param automatically_decided_on: The automatically_decided_on of this DeliveryIndication.
        :type: datetime
        """

        self._automatically_decided_on = automatically_decided_on
    
    @property
    def completion(self):
        """Gets the completion of this DeliveryIndication.

            

        :return: The completion of this DeliveryIndication.
        :rtype: int
        """
        return self._completion

    @completion.setter
    def completion(self, completion):
        """Sets the completion of this DeliveryIndication.

            

        :param completion: The completion of this DeliveryIndication.
        :type: int
        """

        self._completion = completion
    
    @property
    def created_on(self):
        """Gets the created_on of this DeliveryIndication.

            The date and time when the object was created.

        :return: The created_on of this DeliveryIndication.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this DeliveryIndication.

            The date and time when the object was created.

        :param created_on: The created_on of this DeliveryIndication.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def manual_decision_timeout_on(self):
        """Gets the manual_decision_timeout_on of this DeliveryIndication.

            

        :return: The manual_decision_timeout_on of this DeliveryIndication.
        :rtype: datetime
        """
        return self._manual_decision_timeout_on

    @manual_decision_timeout_on.setter
    def manual_decision_timeout_on(self, manual_decision_timeout_on):
        """Sets the manual_decision_timeout_on of this DeliveryIndication.

            

        :param manual_decision_timeout_on: The manual_decision_timeout_on of this DeliveryIndication.
        :type: datetime
        """

        self._manual_decision_timeout_on = manual_decision_timeout_on
    
    @property
    def manually_decided_by(self):
        """Gets the manually_decided_by of this DeliveryIndication.

            

        :return: The manually_decided_by of this DeliveryIndication.
        :rtype: int
        """
        return self._manually_decided_by

    @manually_decided_by.setter
    def manually_decided_by(self, manually_decided_by):
        """Sets the manually_decided_by of this DeliveryIndication.

            

        :param manually_decided_by: The manually_decided_by of this DeliveryIndication.
        :type: int
        """

        self._manually_decided_by = manually_decided_by
    
    @property
    def manually_decided_on(self):
        """Gets the manually_decided_on of this DeliveryIndication.

            

        :return: The manually_decided_on of this DeliveryIndication.
        :rtype: datetime
        """
        return self._manually_decided_on

    @manually_decided_on.setter
    def manually_decided_on(self, manually_decided_on):
        """Sets the manually_decided_on of this DeliveryIndication.

            

        :param manually_decided_on: The manually_decided_on of this DeliveryIndication.
        :type: datetime
        """

        self._manually_decided_on = manually_decided_on
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this DeliveryIndication.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this DeliveryIndication.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this DeliveryIndication.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this DeliveryIndication.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def state(self):
        """Gets the state of this DeliveryIndication.

            The object's current state.

        :return: The state of this DeliveryIndication.
        :rtype: DeliveryIndicationState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this DeliveryIndication.

            The object's current state.

        :param state: The state of this DeliveryIndication.
        :type: DeliveryIndicationState
        """

        self._state = state
    
    @property
    def timeout_on(self):
        """Gets the timeout_on of this DeliveryIndication.

            

        :return: The timeout_on of this DeliveryIndication.
        :rtype: datetime
        """
        return self._timeout_on

    @timeout_on.setter
    def timeout_on(self, timeout_on):
        """Sets the timeout_on of this DeliveryIndication.

            

        :param timeout_on: The timeout_on of this DeliveryIndication.
        :type: datetime
        """

        self._timeout_on = timeout_on
    
    @property
    def transaction(self):
        """Gets the transaction of this DeliveryIndication.

            

        :return: The transaction of this DeliveryIndication.
        :rtype: Transaction
        """
        return self._transaction

    @transaction.setter
    def transaction(self, transaction):
        """Sets the transaction of this DeliveryIndication.

            

        :param transaction: The transaction of this DeliveryIndication.
        :type: Transaction
        """

        self._transaction = transaction
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(DeliveryIndication, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, DeliveryIndication):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class SubscriptionChargeCreate:

    swagger_types = {
    
        'external_id': 'str',
        'failed_url': 'str',
        'planned_execution_date': 'datetime',
        'processing_type': 'SubscriptionChargeProcessingType',
        'reference': 'str',
        'subscription': 'int',
        'success_url': 'str',
    }

    attribute_map = {
        'external_id': 'externalId','failed_url': 'failedUrl','planned_execution_date': 'plannedExecutionDate','processing_type': 'processingType','reference': 'reference','subscription': 'subscription','success_url': 'successUrl',
    }

    
    _external_id = None
    _failed_url = None
    _planned_execution_date = None
    _processing_type = None
    _reference = None
    _subscription = None
    _success_url = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.external_id = kwargs.get('external_id')

        self.failed_url = kwargs.get('failed_url', None)
        self.planned_execution_date = kwargs.get('planned_execution_date', None)
        self.processing_type = kwargs.get('processing_type')

        self.reference = kwargs.get('reference', None)
        self.subscription = kwargs.get('subscription')

        self.success_url = kwargs.get('success_url', None)
        

    
    @property
    def external_id(self):
        """Gets the external_id of this SubscriptionChargeCreate.

            A client generated nonce which identifies the entity to be created. Subsequent creation requests with the same external ID will not create new entities but return the initially created entity instead.

        :return: The external_id of this SubscriptionChargeCreate.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this SubscriptionChargeCreate.

            A client generated nonce which identifies the entity to be created. Subsequent creation requests with the same external ID will not create new entities but return the initially created entity instead.

        :param external_id: The external_id of this SubscriptionChargeCreate.
        :type: str
        """
        if external_id is None:
            raise ValueError("Invalid value for `external_id`, must not be `None`")

        self._external_id = external_id
    
    @property
    def failed_url(self):
        """Gets the failed_url of this SubscriptionChargeCreate.

            The user will be redirected to failed URL when the transaction could not be authorized or completed. In case no failed URL is specified a default failed page will be displayed.

        :return: The failed_url of this SubscriptionChargeCreate.
        :rtype: str
        """
        return self._failed_url

    @failed_url.setter
    def failed_url(self, failed_url):
        """Sets the failed_url of this SubscriptionChargeCreate.

            The user will be redirected to failed URL when the transaction could not be authorized or completed. In case no failed URL is specified a default failed page will be displayed.

        :param failed_url: The failed_url of this SubscriptionChargeCreate.
        :type: str
        """
        if failed_url is not None and len(failed_url) > 500:
            raise ValueError("Invalid value for `failed_url`, length must be less than or equal to `500`")
        if failed_url is not None and len(failed_url) < 9:
            raise ValueError("Invalid value for `failed_url`, length must be greater than or equal to `9`")

        self._failed_url = failed_url
    
    @property
    def planned_execution_date(self):
        """Gets the planned_execution_date of this SubscriptionChargeCreate.

            

        :return: The planned_execution_date of this SubscriptionChargeCreate.
        :rtype: datetime
        """
        return self._planned_execution_date

    @planned_execution_date.setter
    def planned_execution_date(self, planned_execution_date):
        """Sets the planned_execution_date of this SubscriptionChargeCreate.

            

        :param planned_execution_date: The planned_execution_date of this SubscriptionChargeCreate.
        :type: datetime
        """

        self._planned_execution_date = planned_execution_date
    
    @property
    def processing_type(self):
        """Gets the processing_type of this SubscriptionChargeCreate.

            

        :return: The processing_type of this SubscriptionChargeCreate.
        :rtype: SubscriptionChargeProcessingType
        """
        return self._processing_type

    @processing_type.setter
    def processing_type(self, processing_type):
        """Sets the processing_type of this SubscriptionChargeCreate.

            

        :param processing_type: The processing_type of this SubscriptionChargeCreate.
        :type: SubscriptionChargeProcessingType
        """
        if processing_type is None:
            raise ValueError("Invalid value for `processing_type`, must not be `None`")

        self._processing_type = processing_type
    
    @property
    def reference(self):
        """Gets the reference of this SubscriptionChargeCreate.

            

        :return: The reference of this SubscriptionChargeCreate.
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this SubscriptionChargeCreate.

            

        :param reference: The reference of this SubscriptionChargeCreate.
        :type: str
        """
        if reference is not None and len(reference) > 100:
            raise ValueError("Invalid value for `reference`, length must be less than or equal to `100`")

        self._reference = reference
    
    @property
    def subscription(self):
        """Gets the subscription of this SubscriptionChargeCreate.

            The field subscription indicates the subscription to which the charge belongs to.

        :return: The subscription of this SubscriptionChargeCreate.
        :rtype: int
        """
        return self._subscription

    @subscription.setter
    def subscription(self, subscription):
        """Sets the subscription of this SubscriptionChargeCreate.

            The field subscription indicates the subscription to which the charge belongs to.

        :param subscription: The subscription of this SubscriptionChargeCreate.
        :type: int
        """
        if subscription is None:
            raise ValueError("Invalid value for `subscription`, must not be `None`")

        self._subscription = subscription
    
    @property
    def success_url(self):
        """Gets the success_url of this SubscriptionChargeCreate.

            The user will be redirected to success URL when the transaction could be authorized or completed. In case no success URL is specified a default success page will be displayed.

        :return: The success_url of this SubscriptionChargeCreate.
        :rtype: str
        """
        return self._success_url

    @success_url.setter
    def success_url(self, success_url):
        """Sets the success_url of this SubscriptionChargeCreate.

            The user will be redirected to success URL when the transaction could be authorized or completed. In case no success URL is specified a default success page will be displayed.

        :param success_url: The success_url of this SubscriptionChargeCreate.
        :type: str
        """
        if success_url is not None and len(success_url) > 500:
            raise ValueError("Invalid value for `success_url`, length must be less than or equal to `500`")
        if success_url is not None and len(success_url) < 9:
            raise ValueError("Invalid value for `success_url`, length must be greater than or equal to `9`")

        self._success_url = success_url
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(SubscriptionChargeCreate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, SubscriptionChargeCreate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
